@@ -11,11 +11,14 @@
 #include "cut-listener-utils.h"
 #include "cut-main.h"
 #include "cut-test.h"
-#include "cut-test-case.h"
+#include "cut-iterated-test.h"
 #include "cut-test-container.h"
-#include "cut-test-context.h"
+#include "cut-test-iterator.h"
+#include "cut-test-case.h"
 #include "cut-test-suite.h"
+#include "cut-test-context.h"
 #include "cut-test-result.h"
+#include "cut-test-data.h"
 #include "cut-ui.h"
 #include "cut-contractor.h"
 #include "cut-factory-builder.h"
@@ -47,6 +50,7 @@ cut_test_result_status_get_type (void)
       { CUT_TEST_RESULT_PENDING, "CUT_TEST_RESULT_PENDING", "pending" },
       { CUT_TEST_RESULT_FAILURE, "CUT_TEST_RESULT_FAILURE", "failure" },
       { CUT_TEST_RESULT_ERROR, "CUT_TEST_RESULT_ERROR", "error" },
+      { CUT_TEST_RESULT_LAST, "CUT_TEST_RESULT_LAST", "last" },
       { 0, NULL, NULL }
     };
     etype = g_enum_register_static ("CutTestResultStatus", values);
