@@ -23,8 +23,26 @@
 
 #include <stdlib.h>
 #include <string.h>
-#include <sys/wait.h>
-#include <unistd.h>
+#include <fcntl.h>
+#include <errno.h>
+
+#ifdef HAVE_UNISTD_H
+#  include <unistd.h>
+#endif
+#ifdef HAVE_SYS_WAIT_H
+#  include <sys/wait.h>
+#endif
+#ifndef WIFEXITED
+#  define WIFEXITED(status) (TRUE)
+#endif
+#ifndef WEXITSTATUS
+#  define WEXITSTATUS(status) (status)
+#endif
+#ifdef HAVE_IO_H
+#  include <io.h>
+#  define pipe(phandles) _pipe(phandles, 4096, _O_BINARY)
+#endif
+
 #include <glib.h>
 
 #include "cut-pipeline.h"
@@ -312,11 +330,17 @@ create_child_out_channel (CutPipeline *pipeline)
     CutPipelinePrivate *priv;
 
     priv = CUT_PIPELINE_GET_PRIVATE(pipeline);
-#ifdef G_OS_WIN32
-    channel = g_io_channel_win32_new_fd(priv->child_pipe[CUT_READ]);
-#else
+    if (priv->child_pipe[CUT_READ] == -1)
+        return NULL;
+
+#ifndef G_OS_WIN32
     channel = g_io_channel_unix_new(priv->child_pipe[CUT_READ]);
+#else
+    channel = g_io_channel_win32_new_fd(priv->child_pipe[CUT_READ]);
 #endif
+    if (!channel)
+        return NULL;
+
     g_io_channel_set_close_on_unref(channel, TRUE);
     priv->child_out_source_id = g_io_add_watch(channel,
                                                G_IO_IN | G_IO_PRI |
@@ -367,19 +391,13 @@ create_command_line_args (CutPipeline *pipeline)
         gboolean result;
         gint argc;
         gchar *command_line;
-        const gchar *cutter_command = NULL;
 
-        cutter_command = g_getenv("CUTTER");
-
-        if (!cutter_command)
-            cutter_command = g_get_prgname();
-
-        command_line = g_strdup_printf("%s "
+        command_line = g_strdup_printf("\"%s\" "
                                        "-v s "
                                        "--streamer=xml "
                                        "--stream-fd=%d "
-                                       "%s",
-                                       cutter_command,
+                                       "\"%s\"",
+                                       cut_utils_get_cutter_command_path(),
                                        priv->child_pipe[CUT_WRITE],
                                        test_directory);
         result = g_shell_parse_argv(command_line, &argc, &new_args, NULL);
@@ -389,6 +407,7 @@ create_command_line_args (CutPipeline *pipeline)
     return new_args;
 }
 
+#ifndef G_OS_WIN32
 static void
 setup_child (gpointer user_data)
 {
@@ -399,6 +418,7 @@ setup_child (gpointer user_data)
 
     cut_utils_close_pipe(priv->child_pipe, CUT_READ);
 }
+#endif
 
 static void
 run_async (CutPipeline *pipeline)
@@ -426,7 +446,11 @@ run_async (CutPipeline *pipeline)
                                       NULL,
                                       G_SPAWN_LEAVE_DESCRIPTORS_OPEN |
                                       G_SPAWN_DO_NOT_REAP_CHILD,
+#ifndef G_OS_WIN32
                                       setup_child,
+#else
+                                      NULL,
+#endif
                                       pipeline,
                                       &priv->pid,
                                       NULL,
@@ -441,10 +465,20 @@ run_async (CutPipeline *pipeline)
         return;
     }
 
+    if (priv->pid == (GPid)0) {
+        emit_error(pipeline, error, "failed to get child PID");
+        return;
+    }
+
+    priv->child_out = create_child_out_channel(pipeline);
+    if (!priv->child_out) {
+        emit_error(pipeline, error, "failed to connect to child pipe");
+        return;
+    }
+
     priv->error_emitted = FALSE;
     priv->eof = FALSE;
     priv->parser = cut_stream_parser_new(CUT_RUN_CONTEXT(pipeline));
-    priv->child_out = create_child_out_channel(pipeline);
     priv->process_source_id = g_child_watch_add(priv->pid,
                                                 child_watch_func,
                                                 pipeline);
