@@ -1,6 +1,6 @@
 /* -*- Mode: C; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
- *  Copyright (C) 2007  Kouhei Sutou <kou@cozmixng.org>
+ *  Copyright (C) 2007-2008  Kouhei Sutou <kou@cozmixng.org>
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -24,6 +24,8 @@
 extern "C" {
 #endif
 
+#include <cutter/cut-types.h>
+
 #if __GNUC__ > 2 || (__GNUC__ == 2 && __GNUC_MINOR__ > 4)
 #  define CUT_GNUC_PRINTF(format_index, arg_index)                      \
     __attribute__((__format__ (__printf__, format_index, arg_index)))
@@ -34,6 +36,12 @@ extern "C" {
 #  define CUT_GNUC_NORETURN
 #endif
 
+#if __GNUC__ >= 4
+#  define CUT_GNUC_NULL_TERMINATED __attribute__((__sentinel__))
+#else
+#  define CUT_GNUC_NULL_TERMINATED
+#endif
+
 typedef struct _CutTestContext     CutTestContext;
 
 typedef struct _CutTestAttribute CutTestAttribute;
@@ -49,7 +57,8 @@ typedef enum {
     CUT_TEST_RESULT_OMISSION,
     CUT_TEST_RESULT_PENDING,
     CUT_TEST_RESULT_FAILURE,
-    CUT_TEST_RESULT_ERROR
+    CUT_TEST_RESULT_ERROR,
+    CUT_TEST_RESULT_LAST
 } CutTestResultStatus;
 
 void  cut_test_context_pass_assertion       (CutTestContext *context);
@@ -75,13 +84,46 @@ const char **cut_test_context_take_string_array
 int   cut_utils_compare_string_array        (char **strings1,
                                              char **strings2);
 char *cut_utils_inspect_string_array        (char **strings);
+const char *cut_utils_inspect_string        (const char *string);
+
 int   cut_utils_is_interested_diff          (const char *diff);
+
 int   cut_utils_file_exist                  (const char *path);
+char *cut_utils_build_path                  (const char *path,
+                                             ...) CUT_GNUC_NULL_TERMINATED;
+void  cut_utils_remove_path_recursive_force (const char *path);
 
 int   cut_utils_regex_match                 (const char *pattern,
                                              const char *string);
+char *cut_utils_append_diff                 (const char *message,
+                                             const char *from,
+                                             const char *to);
+
+char *cut_test_context_build_fixture_data_path
+                                            (CutTestContext *context,
+                                             const char     *path,
+                                             ...) CUT_GNUC_NULL_TERMINATED;
+
+const char *cut_utils_get_fixture_data_string(CutTestContext *context,
+                                              const char *function,
+                                              const char *file,
+                                              unsigned int line,
+                                              const char *path,
+                                              ...) CUT_GNUC_NULL_TERMINATED;
+
+void  cut_utils_get_fixture_data_string_and_path(CutTestContext *context,
+                                                 const char *function,
+                                                 const char *file,
+                                                 unsigned int line,
+                                                 char **data,
+                                                 char **fixture_data_path,
+                                                 const char *path,
+                                                 ...) CUT_GNUC_NULL_TERMINATED;
+
+void  cut_test_context_add_data             (CutTestContext *context,
+                                             const char     *first_data_name,
+                                             ...) CUT_GNUC_NULL_TERMINATED;
 
-void *cut_test_context_get_user_data        (CutTestContext *context);
 int   cut_test_context_trap_fork            (CutTestContext *context,
                                              const char     *function_name,
                                              const char     *filename,
@@ -96,6 +138,10 @@ const char *cut_test_context_get_forked_stderr_message
                                             (CutTestContext *context,
                                              int             pid);
 
+void  cut_test_context_set_fixture_data_dir (CutTestContext *context,
+                                             const char     *path,
+                                             ...) CUT_GNUC_NULL_TERMINATED;
+
 char       *cut_diff_readable               (const char     *from,
                                              const char     *to);
 
