@@ -50,6 +50,7 @@ struct _CutRunContextPrivate
     guint n_omissions;
     gdouble elapsed;
     GList *results;
+    GList *reversed_results;
     gboolean use_multi_thread;
     gboolean is_multi_thread;
     GMutex *mutex;
@@ -100,7 +101,10 @@ enum
     START_TEST_SUITE,
     READY_TEST_CASE,
     START_TEST_CASE,
+    READY_TEST_ITERATOR,
+    START_TEST_ITERATOR,
     START_TEST,
+    START_ITERATED_TEST,
 
     PASS_ASSERTION,
 
@@ -111,6 +115,13 @@ enum
     NOTIFICATION_TEST,
     OMISSION_TEST,
 
+    SUCCESS_TEST_ITERATOR,
+    FAILURE_TEST_ITERATOR,
+    ERROR_TEST_ITERATOR,
+    PENDING_TEST_ITERATOR,
+    NOTIFICATION_TEST_ITERATOR,
+    OMISSION_TEST_ITERATOR,
+
     SUCCESS_TEST_CASE,
     FAILURE_TEST_CASE,
     ERROR_TEST_CASE,
@@ -118,7 +129,9 @@ enum
     NOTIFICATION_TEST_CASE,
     OMISSION_TEST_CASE,
 
+    COMPLETE_ITERATED_TEST,
     COMPLETE_TEST,
+    COMPLETE_TEST_ITERATOR,
     COMPLETE_TEST_CASE,
     COMPLETE_TEST_SUITE,
     COMPLETE_RUN,
@@ -148,6 +161,10 @@ static void get_property   (GObject         *object,
                             GValue          *value,
                             GParamSpec      *pspec);
 
+static void start_iterated_test
+                           (CutRunContext   *context,
+                            CutIteratedTest *iterated_test,
+                            CutTestContext  *test_context);
 static void start_test     (CutRunContext   *context,
                             CutTest         *test,
                             CutTestContext  *test_context);
@@ -182,6 +199,10 @@ static void omission_test  (CutRunContext   *context,
 static void complete_test  (CutRunContext   *context,
                             CutTest         *test,
                             CutTestContext  *test_context);
+static void complete_iterated_test
+                           (CutRunContext   *context,
+                            CutIteratedTest *iterated_test,
+                            CutTestContext  *test_context);
 static void crashed        (CutRunContext   *context,
                             const gchar     *backtrace);
 
@@ -189,8 +210,14 @@ static void prepare_test_suite  (CutRunContext  *context,
                                  CutTestSuite   *test_suite);
 static void prepare_test_case   (CutRunContext  *context,
                                  CutTestCase    *test_case);
+static void prepare_test_iterator
+                                (CutRunContext  *context,
+                                 CutTestIterator *test_iterator);
 static void prepare_test        (CutRunContext  *context,
                                  CutTest        *test);
+static void prepare_iterated_test
+                                (CutRunContext  *context,
+                                 CutIteratedTest *iterated_test);
 
 static gboolean runner_run (CutRunner *runner);
 
@@ -206,6 +233,7 @@ cut_run_context_class_init (CutRunContextClass *klass)
     gobject_class->set_property = set_property;
     gobject_class->get_property = get_property;
 
+    klass->start_iterated_test = start_iterated_test;
     klass->start_test        = start_test;
     klass->pass_assertion    = pass_assertion;
     klass->success_test      = success_test;
@@ -215,11 +243,14 @@ cut_run_context_class_init (CutRunContextClass *klass)
     klass->notification_test = notification_test;
     klass->omission_test     = omission_test;
     klass->complete_test     = complete_test;
+    klass->complete_iterated_test = complete_iterated_test;
     klass->crashed           = crashed;
 
     klass->prepare_test_suite = prepare_test_suite;
     klass->prepare_test_case = prepare_test_case;
+    klass->prepare_test_iterator = prepare_test_iterator;
     klass->prepare_test = prepare_test;
+    klass->prepare_iterated_test = prepare_iterated_test;
 
     spec = g_param_spec_uint("n-tests",
                              "Number of tests",
@@ -382,13 +413,31 @@ cut_run_context_class_init (CutRunContextClass *klass)
 
     signals[START_TEST_CASE]
         = g_signal_new ("start-test-case",
-                        G_TYPE_FROM_CLASS (klass),
+                        G_TYPE_FROM_CLASS(klass),
                         G_SIGNAL_RUN_LAST,
-                        G_STRUCT_OFFSET (CutRunContextClass, start_test_case),
+                        G_STRUCT_OFFSET(CutRunContextClass, start_test_case),
                         NULL, NULL,
                         g_cclosure_marshal_VOID__OBJECT,
                         G_TYPE_NONE, 1, CUT_TYPE_TEST_CASE);
 
+    signals[READY_TEST_ITERATOR]
+        = g_signal_new ("ready-test-iterator",
+                        G_TYPE_FROM_CLASS(klass),
+                        G_SIGNAL_RUN_LAST,
+                        G_STRUCT_OFFSET(CutRunContextClass, ready_test_iterator),
+                        NULL, NULL,
+                        _cut_marshal_VOID__OBJECT_UINT,
+                        G_TYPE_NONE, 2, CUT_TYPE_TEST_ITERATOR, G_TYPE_UINT);
+
+    signals[START_TEST_ITERATOR]
+        = g_signal_new ("start-test-iterator",
+                        G_TYPE_FROM_CLASS(klass),
+                        G_SIGNAL_RUN_LAST,
+                        G_STRUCT_OFFSET(CutRunContextClass, start_test_iterator),
+                        NULL, NULL,
+                        g_cclosure_marshal_VOID__OBJECT,
+                        G_TYPE_NONE, 1, CUT_TYPE_TEST_ITERATOR);
+
     signals[START_TEST]
         = g_signal_new ("start-test",
                         G_TYPE_FROM_CLASS (klass),
@@ -399,6 +448,16 @@ cut_run_context_class_init (CutRunContextClass *klass)
                         G_TYPE_NONE, 2,
                         CUT_TYPE_TEST, CUT_TYPE_TEST_CONTEXT);
 
+    signals[START_ITERATED_TEST]
+        = g_signal_new("start-iterated-test",
+                       G_TYPE_FROM_CLASS(klass),
+                       G_SIGNAL_RUN_LAST,
+                       G_STRUCT_OFFSET(CutRunContextClass, start_iterated_test),
+                       NULL, NULL,
+                       _cut_marshal_VOID__OBJECT_OBJECT,
+                       G_TYPE_NONE, 2,
+                       CUT_TYPE_ITERATED_TEST, CUT_TYPE_TEST_CONTEXT);
+
     signals[PASS_ASSERTION]
         = g_signal_new ("pass-assertion",
                         G_TYPE_FROM_CLASS (klass),
@@ -474,6 +533,17 @@ cut_run_context_class_init (CutRunContextClass *klass)
                        CUT_TYPE_TEST, CUT_TYPE_TEST_CONTEXT,
                        CUT_TYPE_TEST_RESULT);
 
+    signals[COMPLETE_ITERATED_TEST]
+        = g_signal_new("complete-iterated-test",
+                       G_TYPE_FROM_CLASS(klass),
+                       G_SIGNAL_RUN_LAST,
+                       G_STRUCT_OFFSET(CutRunContextClass,
+                                       complete_iterated_test),
+                       NULL, NULL,
+                       _cut_marshal_VOID__OBJECT_OBJECT,
+                       G_TYPE_NONE,
+                       2, CUT_TYPE_ITERATED_TEST, CUT_TYPE_TEST_CONTEXT);
+
     signals[COMPLETE_TEST]
         = g_signal_new ("complete-test",
                         G_TYPE_FROM_CLASS (klass),
@@ -483,6 +553,69 @@ cut_run_context_class_init (CutRunContextClass *klass)
                         _cut_marshal_VOID__OBJECT_OBJECT,
                         G_TYPE_NONE, 2, CUT_TYPE_TEST, CUT_TYPE_TEST_CONTEXT);
 
+    signals[SUCCESS_TEST_ITERATOR]
+        = g_signal_new("success-test-iterator",
+                       G_TYPE_FROM_CLASS(klass),
+                       G_SIGNAL_RUN_LAST,
+                       G_STRUCT_OFFSET(CutRunContextClass, success_test_iterator),
+                       NULL, NULL,
+                       _cut_marshal_VOID__OBJECT_OBJECT,
+                       G_TYPE_NONE, 2, CUT_TYPE_TEST_ITERATOR, CUT_TYPE_TEST_RESULT);
+
+    signals[FAILURE_TEST_ITERATOR]
+        = g_signal_new("failure-test-iterator",
+                       G_TYPE_FROM_CLASS(klass),
+                       G_SIGNAL_RUN_LAST,
+                       G_STRUCT_OFFSET(CutRunContextClass, failure_test_iterator),
+                       NULL, NULL,
+                       _cut_marshal_VOID__OBJECT_OBJECT,
+                       G_TYPE_NONE, 2, CUT_TYPE_TEST_ITERATOR, CUT_TYPE_TEST_RESULT);
+
+    signals[ERROR_TEST_ITERATOR]
+        = g_signal_new("error-test-iterator",
+                       G_TYPE_FROM_CLASS(klass),
+                       G_SIGNAL_RUN_LAST,
+                       G_STRUCT_OFFSET(CutRunContextClass, error_test_iterator),
+                       NULL, NULL,
+                       _cut_marshal_VOID__OBJECT_OBJECT,
+                       G_TYPE_NONE, 2, CUT_TYPE_TEST_ITERATOR, CUT_TYPE_TEST_RESULT);
+
+    signals[PENDING_TEST_ITERATOR]
+        = g_signal_new("pending-test-iterator",
+                       G_TYPE_FROM_CLASS(klass),
+                       G_SIGNAL_RUN_LAST,
+                       G_STRUCT_OFFSET(CutRunContextClass, pending_test_iterator),
+                       NULL, NULL,
+                       _cut_marshal_VOID__OBJECT_OBJECT,
+                       G_TYPE_NONE, 2, CUT_TYPE_TEST_ITERATOR, CUT_TYPE_TEST_RESULT);
+
+    signals[NOTIFICATION_TEST_ITERATOR]
+        = g_signal_new("notification-test-iterator",
+                       G_TYPE_FROM_CLASS(klass),
+                       G_SIGNAL_RUN_LAST,
+                       G_STRUCT_OFFSET(CutRunContextClass, notification_test_iterator),
+                       NULL, NULL,
+                       _cut_marshal_VOID__OBJECT_OBJECT,
+                       G_TYPE_NONE, 2, CUT_TYPE_TEST_ITERATOR, CUT_TYPE_TEST_RESULT);
+
+    signals[OMISSION_TEST_ITERATOR]
+        = g_signal_new("omission-test-iterator",
+                       G_TYPE_FROM_CLASS (klass),
+                       G_SIGNAL_RUN_LAST,
+                       G_STRUCT_OFFSET(CutRunContextClass, omission_test_iterator),
+                       NULL, NULL,
+                       _cut_marshal_VOID__OBJECT_OBJECT,
+                       G_TYPE_NONE, 2, CUT_TYPE_TEST_ITERATOR, CUT_TYPE_TEST_RESULT);
+
+    signals[COMPLETE_TEST_ITERATOR]
+        = g_signal_new ("complete-test-iterator",
+                        G_TYPE_FROM_CLASS (klass),
+                        G_SIGNAL_RUN_LAST,
+                        G_STRUCT_OFFSET (CutRunContextClass, complete_test_iterator),
+                        NULL, NULL,
+                        g_cclosure_marshal_VOID__OBJECT,
+                        G_TYPE_NONE, 1, CUT_TYPE_TEST_ITERATOR);
+
     signals[SUCCESS_TEST_CASE]
         = g_signal_new("success-test-case",
                        G_TYPE_FROM_CLASS(klass),
@@ -600,6 +733,7 @@ cut_run_context_init (CutRunContext *context)
     priv->n_omissions = 0;
     priv->elapsed = 0.0;
     priv->results = NULL;
+    priv->reversed_results = NULL;
     priv->use_multi_thread = FALSE;
     priv->is_multi_thread = FALSE;
     priv->mutex = g_mutex_new();
@@ -634,6 +768,11 @@ dispose (GObject *object)
         priv->results = NULL;
     }
 
+    if (priv->reversed_results) {
+        g_list_free(priv->reversed_results);
+        priv->reversed_results = NULL;
+    }
+
     if (priv->mutex) {
         g_mutex_free(priv->mutex);
         priv->mutex = NULL;
@@ -844,6 +983,19 @@ start_test (CutRunContext   *context,
     g_mutex_unlock(priv->mutex);
 }
 
+static void
+start_iterated_test (CutRunContext   *context,
+                     CutIteratedTest *iterated_test,
+                     CutTestContext  *test_context)
+{
+    CutRunContextPrivate *priv;
+
+    priv = CUT_RUN_CONTEXT_GET_PRIVATE(context);
+    g_mutex_lock(priv->mutex);
+    priv->n_tests++;
+    g_mutex_unlock(priv->mutex);
+}
+
 static void
 pass_assertion (CutRunContext   *context,
                 CutTest         *test,
@@ -946,6 +1098,19 @@ omission_test (CutRunContext   *context,
     g_mutex_unlock(priv->mutex);
 }
 
+static void
+complete_iterated_test (CutRunContext   *context,
+                        CutIteratedTest *iterated_test,
+                        CutTestContext  *test_context)
+{
+    CutRunContextPrivate *priv;
+
+    priv = CUT_RUN_CONTEXT_GET_PRIVATE(context);
+    g_mutex_lock(priv->mutex);
+    priv->elapsed += cut_test_get_elapsed(CUT_TEST(iterated_test));
+    g_mutex_unlock(priv->mutex);
+}
+
 static void
 complete_test (CutRunContext   *context,
                CutTest         *test,
@@ -1125,6 +1290,22 @@ cut_run_context_prepare_test_case (CutRunContext *context,
         klass->prepare_test_case(context, test_case);
 }
 
+static void
+prepare_test_iterator (CutRunContext *context, CutTestIterator *test_iterator)
+{
+}
+
+void
+cut_run_context_prepare_test_iterator (CutRunContext *context,
+                                       CutTestIterator *test_iterator)
+{
+    CutRunContextClass *klass;
+
+    klass = CUT_RUN_CONTEXT_GET_CLASS(context);
+    if (klass->prepare_test_iterator)
+        klass->prepare_test_iterator(context, test_iterator);
+}
+
 static void
 prepare_test (CutRunContext *context, CutTest *test)
 {
@@ -1140,6 +1321,22 @@ cut_run_context_prepare_test (CutRunContext *context, CutTest *test)
         klass->prepare_test(context, test);
 }
 
+static void
+prepare_iterated_test (CutRunContext *context, CutIteratedTest *iterated_test)
+{
+}
+
+void
+cut_run_context_prepare_iterated_test (CutRunContext *context,
+                                       CutIteratedTest *iterated_test)
+{
+    CutRunContextClass *klass;
+
+    klass = CUT_RUN_CONTEXT_GET_CLASS(context);
+    if (klass->prepare_iterated_test)
+        klass->prepare_iterated_test(context, iterated_test);
+}
+
 guint
 cut_run_context_get_n_tests (CutRunContext *context)
 {
@@ -1197,7 +1394,14 @@ cut_run_context_get_elapsed (CutRunContext *context)
 const GList *
 cut_run_context_get_results (CutRunContext *context)
 {
-    return CUT_RUN_CONTEXT_GET_PRIVATE(context)->results;
+    CutRunContextPrivate *priv;
+
+    priv = CUT_RUN_CONTEXT_GET_PRIVATE(context);
+    if (priv->reversed_results)
+        g_list_free(priv->reversed_results);
+
+    priv->reversed_results = g_list_reverse(g_list_copy(priv->results));
+    return priv->reversed_results;
 }
 
 void
