@@ -36,13 +36,18 @@ typedef enum {
 
     IN_TEST_SUITE,
     IN_TEST_CASE,
+    IN_TEST_ITERATOR,
     IN_TEST,
+    IN_ITERATED_TEST,
+    IN_TEST_DATA,
 
     IN_TEST_NAME,
     IN_TEST_DESCRIPTION,
     IN_TEST_OPTION,
     IN_TEST_ELAPSED,
 
+    IN_TEST_DATA_NAME,
+
     IN_TEST_OPTION_NAME,
     IN_TEST_OPTION_VALUE,
 
@@ -58,10 +63,17 @@ typedef enum {
     IN_READY_TEST_CASE,
     IN_READY_TEST_CASE_N_TESTS,
 
+    IN_READY_TEST_ITERATOR,
+    IN_READY_TEST_ITERATOR_N_TESTS,
+
     IN_START_TEST_CASE,
 
+    IN_START_TEST_ITERATOR,
+
     IN_START_TEST,
 
+    IN_START_ITERATED_TEST,
+
     IN_PASS_ASSERTION,
 
     IN_TEST_RESULT,
@@ -76,10 +88,14 @@ typedef enum {
     IN_RESULT_BACKTRACE_ENTRY_INFO,
     IN_RESULT_ELAPSED,
 
+    IN_COMPLETE_ITERATED_TEST,
+
     IN_COMPLETE_TEST,
 
     IN_TEST_CASE_RESULT,
 
+    IN_COMPLETE_TEST_ITERATOR,
+
     IN_COMPLETE_TEST_CASE,
 
     IN_COMPLETE_TEST_SUITE,
@@ -88,7 +104,9 @@ typedef enum {
     IN_CRASHED_BACKTRACE
 } ParseState;
 
-#define CUT_STREAM_PARSER_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), CUT_TYPE_STREAM_PARSER, CutStreamParserPrivate))
+#define CUT_STREAM_PARSER_GET_PRIVATE(obj)                              \
+    (G_TYPE_INSTANCE_GET_PRIVATE((obj), CUT_TYPE_STREAM_PARSER,         \
+                                 CutStreamParserPrivate))
 
 typedef struct _ReadyTestSuite ReadyTestSuite;
 struct _ReadyTestSuite
@@ -105,6 +123,13 @@ struct _ReadyTestCase
     gint n_tests;
 };
 
+typedef struct _ReadyTestIterator ReadyTestIterator;
+struct _ReadyTestIterator
+{
+    CutTestIterator *test_iterator;
+    gint n_tests;
+};
+
 typedef struct _StartTest StartTest;
 struct _StartTest
 {
@@ -112,6 +137,13 @@ struct _StartTest
     CutTestContext *test_context;
 };
 
+typedef struct _StartIteratedTest StartIteratedTest;
+struct _StartIteratedTest
+{
+    CutIteratedTest *iterated_test;
+    CutTestContext *test_context;
+};
+
 typedef struct _PassAssertion PassAssertion;
 struct _PassAssertion
 {
@@ -127,6 +159,13 @@ struct _TestResult
     CutTestResult *result;
 };
 
+typedef struct _CompleteIteratedTest CompleteIteratedTest;
+struct _CompleteIteratedTest
+{
+    CutIteratedTest *iterated_test;
+    CutTestContext *test_context;
+};
+
 typedef struct _CompleteTest CompleteTest;
 struct _CompleteTest
 {
@@ -148,16 +187,22 @@ struct _CutStreamParserPrivate
     CutRunContext *run_context;
 
     GQueue *states;
+    GQueue *iterated_tests;
     GQueue *tests;
+    GQueue *test_iterators;
     GQueue *test_cases;
     GQueue *test_suites;
     GQueue *test_contexts;
+    GQueue *test_data;
 
     ReadyTestSuite *ready_test_suite;
     ReadyTestCase *ready_test_case;
+    ReadyTestIterator *ready_test_iterator;
     StartTest *start_test;
+    StartIteratedTest *start_iterated_test;
     PassAssertion *pass_assertion;
     TestResult *test_result;
+    CompleteIteratedTest *complete_iterated_test;
     CompleteTest *complete_test;
     TestCaseResult *test_case_result;
 
@@ -188,6 +233,15 @@ struct _CutStreamParserPrivate
 #define PEEK_TEST(priv)                         \
     (g_queue_peek_head((priv)->tests))
 
+#define PUSH_TEST_ITERATOR(priv, test_iterator)                         \
+    (g_queue_push_head((priv)->test_iterators, g_object_ref(test_iterator)))
+#define POP_TEST_ITERATOR(priv)                 \
+    (g_queue_pop_head((priv)->test_iterators))
+#define DROP_TEST_ITERATOR(priv)                \
+    (g_object_unref(POP_TEST_ITERATOR(priv)))
+#define PEEK_TEST_ITERATOR(priv)                \
+    (g_queue_peek_head((priv)->test_iterators))
+
 #define PUSH_TEST_CASE(priv, test_case)                                 \
     (g_queue_push_head((priv)->test_cases, g_object_ref(test_case)))
 #define POP_TEST_CASE(priv)                     \
@@ -215,6 +269,15 @@ struct _CutStreamParserPrivate
 #define PEEK_TEST_CONTEXT(priv)                 \
     (g_queue_peek_head((priv)->test_contexts))
 
+#define PUSH_TEST_DATA(priv, current_test_data)                         \
+    (g_queue_push_head((priv)->test_data, g_object_ref(current_test_data)))
+#define POP_TEST_DATA(priv)                     \
+    (g_queue_pop_head((priv)->test_data))
+#define DROP_TEST_DATA(priv)                    \
+    (g_object_unref(POP_TEST_DATA(priv)))
+#define PEEK_TEST_DATA(priv)                    \
+    (g_queue_peek_head((priv)->test_data))
+
 enum
 {
     PROP_0,
@@ -311,15 +374,21 @@ cut_stream_parser_init (CutStreamParser *stream_parser)
 
     priv->states = g_queue_new();
     PUSH_STATE(priv, IN_TOP_LEVEL);
+    priv->iterated_tests = g_queue_new();
     priv->tests = g_queue_new();
     priv->test_cases = g_queue_new();
+    priv->test_iterators = g_queue_new();
     priv->test_suites = g_queue_new();
     priv->test_contexts = g_queue_new();
+    priv->test_data = g_queue_new();
 
     priv->ready_test_suite = NULL;
     priv->ready_test_case = NULL;
+    priv->ready_test_iterator = NULL;
     priv->start_test = NULL;
+    priv->start_iterated_test = NULL;
     priv->pass_assertion = NULL;
+    priv->complete_iterated_test = NULL;
     priv->complete_test = NULL;
     priv->test_result = NULL;
     priv->test_case_result = NULL;
@@ -359,6 +428,20 @@ ready_test_case_free (ReadyTestCase *ready_test_case)
     g_slice_free(ReadyTestCase, ready_test_case);
 }
 
+static ReadyTestIterator *
+ready_test_iterator_new (void)
+{
+    return g_slice_new0(ReadyTestIterator);
+}
+
+static void
+ready_test_iterator_free (ReadyTestIterator *ready_test_iterator)
+{
+    if (ready_test_iterator->test_iterator)
+        g_object_unref(ready_test_iterator->test_iterator);
+    g_slice_free(ReadyTestIterator, ready_test_iterator);
+}
+
 static StartTest *
 start_test_new (void)
 {
@@ -375,6 +458,22 @@ start_test_free (StartTest *start_test)
     g_slice_free(StartTest, start_test);
 }
 
+static StartIteratedTest *
+start_iterated_test_new (void)
+{
+    return g_slice_new0(StartIteratedTest);
+}
+
+static void
+start_iterated_test_free (StartIteratedTest *start_iterated_test)
+{
+    if (start_iterated_test->iterated_test)
+        g_object_unref(start_iterated_test->iterated_test);
+    if (start_iterated_test->test_context)
+        g_object_unref(start_iterated_test->test_context);
+    g_slice_free(StartIteratedTest, start_iterated_test);
+}
+
 static PassAssertion *
 pass_assertion_new (void)
 {
@@ -409,6 +508,22 @@ test_result_free (TestResult *test_result)
     g_slice_free(TestResult, test_result);
 }
 
+static CompleteIteratedTest *
+complete_iterated_test_new (void)
+{
+    return g_slice_new0(CompleteIteratedTest);
+}
+
+static void
+complete_iterated_test_free (CompleteIteratedTest *complete_iterated_test)
+{
+    if (complete_iterated_test->iterated_test)
+        g_object_unref(complete_iterated_test->iterated_test);
+    if (complete_iterated_test->test_context)
+        g_object_unref(complete_iterated_test->test_context);
+    g_slice_free(CompleteIteratedTest, complete_iterated_test);
+}
+
 static CompleteTest *
 complete_test_new (void)
 {
@@ -464,6 +579,12 @@ dispose (GObject *object)
         priv->states = NULL;
     }
 
+    if (priv->iterated_tests) {
+        g_queue_foreach(priv->iterated_tests, (GFunc)g_object_unref, NULL);
+        g_queue_free(priv->iterated_tests);
+        priv->iterated_tests = NULL;
+    }
+
     if (priv->tests) {
         g_queue_foreach(priv->tests, (GFunc)g_object_unref, NULL);
         g_queue_free(priv->tests);
@@ -488,6 +609,12 @@ dispose (GObject *object)
         priv->test_contexts = NULL;
     }
 
+    if (priv->test_data) {
+        g_queue_foreach(priv->test_data, (GFunc)g_object_unref, NULL);
+        g_queue_free(priv->test_data);
+        priv->test_data = NULL;
+    }
+
     if (priv->ready_test_suite) {
         ready_test_suite_free(priv->ready_test_suite);
         priv->ready_test_suite = NULL;
@@ -503,6 +630,11 @@ dispose (GObject *object)
         priv->start_test = NULL;
     }
 
+    if (priv->start_iterated_test) {
+        start_iterated_test_free(priv->start_iterated_test);
+        priv->start_iterated_test = NULL;
+    }
+
     if (priv->pass_assertion) {
         pass_assertion_free(priv->pass_assertion);
         priv->pass_assertion = NULL;
@@ -513,6 +645,11 @@ dispose (GObject *object)
         priv->test_result = NULL;
     }
 
+    if (priv->complete_iterated_test) {
+        complete_iterated_test_free(priv->complete_iterated_test);
+        priv->complete_iterated_test = NULL;
+    }
+
     if (priv->complete_test) {
         complete_test_free(priv->complete_test);
         priv->complete_test = NULL;
@@ -723,12 +860,26 @@ start_stream (CutStreamParserPrivate *priv,
     } else if (g_str_equal("start-test-case", element_name)) {
         PUSH_STATE(priv, IN_START_TEST_CASE);
         PUSH_TEST_CASE(priv, cut_test_case_new_empty());
+    } else if (g_str_equal("ready-test-iterator", element_name)) {
+        PUSH_STATE(priv, IN_READY_TEST_ITERATOR);
+        priv->ready_test_iterator = ready_test_iterator_new();;
+    } else if (g_str_equal("start-test-iterator", element_name)) {
+        PUSH_STATE(priv, IN_START_TEST_ITERATOR);
+        PUSH_TEST_ITERATOR(priv, cut_test_iterator_new_empty());
     } else if (g_str_equal("start-test", element_name)) {
         PUSH_STATE(priv, IN_START_TEST);
         priv->start_test = start_test_new();
+    } else if (g_str_equal("start-iterated-test", element_name)) {
+        PUSH_STATE(priv, IN_START_ITERATED_TEST);
+        priv->start_iterated_test = start_iterated_test_new();
+    } else if (g_str_equal("complete-iterated-test", element_name)) {
+        PUSH_STATE(priv, IN_COMPLETE_ITERATED_TEST);
+        priv->complete_iterated_test = complete_iterated_test_new();
     } else if (g_str_equal("complete-test", element_name)) {
         PUSH_STATE(priv, IN_COMPLETE_TEST);
         priv->complete_test = complete_test_new();
+    } else if (g_str_equal("complete-test-iterator", element_name)) {
+        PUSH_STATE(priv, IN_COMPLETE_TEST_ITERATOR);
     } else if (g_str_equal("test-case-result", element_name)) {
         PUSH_STATE(priv, IN_TEST_CASE_RESULT);
         priv->test_case_result = test_case_result_new();
@@ -747,8 +898,8 @@ start_stream (CutStreamParserPrivate *priv,
 
 static void
 start_ready_test_suite (CutStreamParserPrivate *priv,
-                                GMarkupParseContext *context,
-                                const gchar *element_name, GError **error)
+                        GMarkupParseContext *context,
+                        const gchar *element_name, GError **error)
 {
     if (g_str_equal("test-suite", element_name)) {
         PUSH_STATE(priv, IN_TEST_SUITE);
@@ -765,8 +916,8 @@ start_ready_test_suite (CutStreamParserPrivate *priv,
 
 static void
 start_start_test_suite (CutStreamParserPrivate *priv,
-                                GMarkupParseContext *context,
-                                const gchar *element_name, GError **error)
+                        GMarkupParseContext *context,
+                        const gchar *element_name, GError **error)
 {
     if (g_str_equal("test-suite", element_name)) {
         PUSH_STATE(priv, IN_TEST_SUITE);
@@ -778,8 +929,8 @@ start_start_test_suite (CutStreamParserPrivate *priv,
 
 static void
 start_ready_test_case (CutStreamParserPrivate *priv,
-                               GMarkupParseContext *context,
-                               const gchar *element_name, GError **error)
+                       GMarkupParseContext *context,
+                       const gchar *element_name, GError **error)
 {
     if (g_str_equal("test-case", element_name)) {
         PUSH_STATE(priv, IN_TEST_CASE);
@@ -794,8 +945,8 @@ start_ready_test_case (CutStreamParserPrivate *priv,
 
 static void
 start_start_test_case (CutStreamParserPrivate *priv,
-                          GMarkupParseContext *context,
-                          const gchar *element_name, GError **error)
+                       GMarkupParseContext *context,
+                       const gchar *element_name, GError **error)
 {
     if (g_str_equal("test-case", element_name)) {
         PUSH_STATE(priv, IN_TEST_CASE);
@@ -805,6 +956,35 @@ start_start_test_case (CutStreamParserPrivate *priv,
     }
 }
 
+static void
+start_ready_test_iterator (CutStreamParserPrivate *priv,
+                           GMarkupParseContext *context,
+                           const gchar *element_name, GError **error)
+{
+    if (g_str_equal("test-iterator", element_name)) {
+        PUSH_STATE(priv, IN_TEST_ITERATOR);
+        priv->ready_test_iterator->test_iterator = cut_test_iterator_new_empty();
+        PUSH_TEST_ITERATOR(priv, priv->ready_test_iterator->test_iterator);
+    } else if (g_str_equal("n-tests", element_name)) {
+        PUSH_STATE(priv, IN_READY_TEST_ITERATOR_N_TESTS);
+    } else {
+        invalid_element(context, error);
+    }
+}
+
+static void
+start_start_test_iterator (CutStreamParserPrivate *priv,
+                          GMarkupParseContext *context,
+                          const gchar *element_name, GError **error)
+{
+    if (g_str_equal("test-iterator", element_name)) {
+        PUSH_STATE(priv, IN_TEST_ITERATOR);
+        PUSH_TEST_ITERATOR(priv, cut_test_iterator_new_empty());
+    } else {
+        invalid_element(context, error);
+    }
+}
+
 static void
 start_start_test (CutStreamParserPrivate *priv,
                   GMarkupParseContext *context,
@@ -823,6 +1003,24 @@ start_start_test (CutStreamParserPrivate *priv,
     }
 }
 
+static void
+start_start_iterated_test (CutStreamParserPrivate *priv,
+                           GMarkupParseContext *context,
+                           const gchar *element_name, GError **error)
+{
+    if (g_str_equal("iterated-test", element_name)) {
+        PUSH_STATE(priv, IN_ITERATED_TEST);
+        priv->start_iterated_test->iterated_test = cut_iterated_test_new_empty();
+        PUSH_TEST(priv, CUT_TEST(priv->start_iterated_test->iterated_test));
+    } else if (g_str_equal("test-context", element_name)) {
+        PUSH_STATE(priv, IN_TEST_CONTEXT);
+        priv->start_iterated_test->test_context = cut_test_context_new_empty();
+        PUSH_TEST_CONTEXT(priv,  priv->start_iterated_test->test_context);
+    } else {
+        invalid_element(context, error);
+    }
+}
+
 static void
 start_pass_assertion (CutStreamParserPrivate *priv,
                       GMarkupParseContext *context,
@@ -843,8 +1041,8 @@ start_pass_assertion (CutStreamParserPrivate *priv,
 
 static void
 start_test_result (CutStreamParserPrivate *priv,
-                           GMarkupParseContext *context,
-                           const gchar *element_name, GError **error)
+                   GMarkupParseContext *context,
+                   const gchar *element_name, GError **error)
 {
     if (g_str_equal("test", element_name)) {
         PUSH_STATE(priv, IN_TEST);
@@ -909,6 +1107,26 @@ start_result (CutStreamParserPrivate *priv, GMarkupParseContext *context,
     }
 }
 
+static void
+start_complete_iterated_test (CutStreamParserPrivate *priv,
+                              GMarkupParseContext *context,
+                              const gchar *element_name, GError **error)
+{
+    if (g_str_equal("iterated-test", element_name)) {
+        PUSH_STATE(priv, IN_ITERATED_TEST);
+        priv->complete_iterated_test->iterated_test =
+            cut_iterated_test_new_empty();
+        PUSH_TEST(priv, CUT_TEST(priv->complete_iterated_test->iterated_test));
+    } else if (g_str_equal("test-context", element_name)) {
+        PUSH_STATE(priv, IN_TEST_CONTEXT);
+        priv->complete_iterated_test->test_context =
+            cut_test_context_new_empty();
+        PUSH_TEST_CONTEXT(priv, priv->complete_iterated_test->test_context);
+    } else {
+        invalid_element(context, error);
+    }
+}
+
 static void
 start_complete_test (CutStreamParserPrivate *priv, GMarkupParseContext *context,
                      const gchar *element_name, GError **error)
@@ -926,6 +1144,19 @@ start_complete_test (CutStreamParserPrivate *priv, GMarkupParseContext *context,
     }
 }
 
+static void
+start_complete_test_iterator (CutStreamParserPrivate *priv,
+                              GMarkupParseContext *context,
+                              const gchar *element_name, GError **error)
+{
+    if (g_str_equal("test-iterator", element_name)) {
+        PUSH_STATE(priv, IN_TEST_ITERATOR);
+        PUSH_TEST_ITERATOR(priv, cut_test_iterator_new_empty());
+    } else {
+        invalid_element(context, error);
+    }
+}
+
 static void
 start_test_case_result (CutStreamParserPrivate *priv,
                         GMarkupParseContext *context,
@@ -1059,6 +1290,15 @@ start_test_context (CutStreamParserPrivate *priv, GMarkupParseContext *context,
         cut_test_context_set_test_case(PEEK_TEST_CONTEXT(priv), test_case);
         PUSH_TEST_CASE(priv, test_case);
         g_object_unref(test_case);
+    } else if (g_str_equal("test-iterator", element_name)) {
+        CutTestIterator *test_iterator;
+
+        PUSH_STATE(priv, IN_TEST_ITERATOR);
+        test_iterator = cut_test_iterator_new_empty();
+        cut_test_context_set_test_iterator(PEEK_TEST_CONTEXT(priv),
+                                           test_iterator);
+        PUSH_TEST_ITERATOR(priv, test_iterator);
+        g_object_unref(test_iterator);
     } else if (g_str_equal("test", element_name)) {
         CutTest *test;
 
@@ -1067,6 +1307,23 @@ start_test_context (CutStreamParserPrivate *priv, GMarkupParseContext *context,
         cut_test_context_set_test(PEEK_TEST_CONTEXT(priv), test);
         PUSH_TEST(priv, test);
         g_object_unref(test);
+    } else if (g_str_equal("iterated-test", element_name)) {
+        CutIteratedTest *iterated_test;
+
+        PUSH_STATE(priv, IN_ITERATED_TEST);
+        iterated_test = cut_iterated_test_new_empty();
+        cut_test_context_set_test(PEEK_TEST_CONTEXT(priv),
+                                  CUT_TEST(iterated_test));
+        PUSH_TEST(priv, CUT_TEST(iterated_test));
+        g_object_unref(iterated_test);
+    } else if (g_str_equal("test-data", element_name)) {
+        CutTestData *test_data;
+
+        PUSH_STATE(priv, IN_TEST_DATA);
+        test_data = cut_test_data_new_empty();
+        cut_test_context_set_data(PEEK_TEST_CONTEXT(priv), test_data);
+        PUSH_TEST_DATA(priv, test_data);
+        g_object_unref(test_data);
     } else if (g_str_equal("failed", element_name)) {
         PUSH_STATE(priv, IN_TEST_CONTEXT_FAILED);
     } else {
@@ -1074,6 +1331,17 @@ start_test_context (CutStreamParserPrivate *priv, GMarkupParseContext *context,
     }
 }
 
+static void
+start_test_data (CutStreamParserPrivate *priv, GMarkupParseContext *context,
+                 const gchar *element_name, GError **error)
+{
+    if (g_str_equal("name", element_name)) {
+        PUSH_STATE(priv, IN_TEST_DATA_NAME);
+    } else {
+        invalid_element(context, error);
+    }
+}
+
 static void
 start_element_handler (GMarkupParseContext *context,
                        const gchar         *element_name,
@@ -1108,9 +1376,18 @@ start_element_handler (GMarkupParseContext *context,
       case IN_START_TEST_CASE:
         start_start_test_case(priv, context, element_name, error);
         break;
+      case IN_READY_TEST_ITERATOR:
+        start_ready_test_iterator(priv, context, element_name, error);
+        break;
+      case IN_START_TEST_ITERATOR:
+        start_start_test_iterator(priv, context, element_name, error);
+        break;
       case IN_START_TEST:
         start_start_test(priv, context, element_name, error);
         break;
+      case IN_START_ITERATED_TEST:
+        start_start_iterated_test(priv, context, element_name, error);
+        break;
       case IN_PASS_ASSERTION:
         start_pass_assertion(priv, context, element_name, error);
         break;
@@ -1123,9 +1400,15 @@ start_element_handler (GMarkupParseContext *context,
       case IN_RESULT:
         start_result(priv, context, element_name, error);
         break;
+      case IN_COMPLETE_ITERATED_TEST:
+        start_complete_iterated_test(priv, context, element_name, error);
+        break;
       case IN_COMPLETE_TEST:
         start_complete_test(priv, context, element_name, error);
         break;
+      case IN_COMPLETE_TEST_ITERATOR:
+        start_complete_test_iterator(priv, context, element_name, error);
+        break;
       case IN_TEST_CASE_RESULT:
         start_test_case_result(priv, context, element_name, error);
         break;
@@ -1140,7 +1423,9 @@ start_element_handler (GMarkupParseContext *context,
         break;
       case IN_TEST_SUITE:
       case IN_TEST_CASE:
+      case IN_TEST_ITERATOR:
       case IN_TEST:
+      case IN_ITERATED_TEST:
         start_test_object(priv, context, element_name, error);
         break;
       case IN_TEST_OPTION:
@@ -1155,6 +1440,9 @@ start_element_handler (GMarkupParseContext *context,
       case IN_TEST_CONTEXT:
         start_test_context(priv, context, element_name, error);
         break;
+      case IN_TEST_DATA:
+        start_test_data(priv, context, element_name, error);
+        break;
       default:
         invalid_element(context, error);
         break;
@@ -1204,8 +1492,12 @@ end_test_context (CutStreamParser *parser, CutStreamParserPrivate *priv,
         DROP_TEST_SUITE(priv);
     if (cut_test_context_get_test_case(test_context))
         DROP_TEST_CASE(priv);
+    if (cut_test_context_get_test_iterator(test_context))
+        DROP_TEST_ITERATOR(priv);
     if (cut_test_context_get_test(test_context))
         DROP_TEST(priv);
+    if (cut_test_context_have_data(test_context))
+        DROP_TEST_DATA(priv);
 }
 
 static void
@@ -1312,6 +1604,48 @@ end_start_test_case (CutStreamParser *parser, CutStreamParserPrivate *priv,
     g_object_unref(test_case);
 }
 
+static void
+end_ready_test_iterator (CutStreamParser *parser, CutStreamParserPrivate *priv,
+                         GMarkupParseContext *context,
+                         const gchar *element_name, GError **error)
+{
+    if (!priv->ready_test_iterator)
+        return;
+
+    if (priv->run_context) {
+        cut_run_context_prepare_test_iterator(
+            priv->run_context,
+            priv->ready_test_iterator->test_iterator);
+        g_signal_emit_by_name(priv->run_context, "ready-test-iterator",
+                              priv->ready_test_iterator->test_iterator,
+                              priv->ready_test_iterator->n_tests);
+    }
+
+    if (priv->ready_test_iterator->test_iterator)
+        DROP_TEST_ITERATOR(priv);
+    ready_test_iterator_free(priv->ready_test_iterator);
+    priv->ready_test_iterator = NULL;
+}
+
+static void
+end_start_test_iterator (CutStreamParser *parser, CutStreamParserPrivate *priv,
+                         GMarkupParseContext *context,
+                         const gchar *element_name, GError **error)
+{
+    CutTestIterator *test_iterator;
+
+    test_iterator = POP_TEST_ITERATOR(priv);
+    if (!test_iterator)
+        return;
+
+    if (priv->run_context)
+        g_signal_emit_by_name(priv->run_context,
+                              "start-test-iterator",
+                              test_iterator);
+
+    g_object_unref(test_iterator);
+}
+
 static void
 end_start_test (CutStreamParser *parser, CutStreamParserPrivate *priv,
                 GMarkupParseContext *context,
@@ -1335,6 +1669,32 @@ end_start_test (CutStreamParser *parser, CutStreamParserPrivate *priv,
     priv->start_test = NULL;
 }
 
+static void
+end_start_iterated_test (CutStreamParser *parser, CutStreamParserPrivate *priv,
+                         GMarkupParseContext *context,
+                         const gchar *element_name, GError **error)
+{
+    if (!priv->start_iterated_test)
+        return;
+
+    if (priv->run_context) {
+        CutIteratedTest *iterated_test;
+
+        iterated_test = priv->start_iterated_test->iterated_test;
+        cut_run_context_prepare_iterated_test(priv->run_context, iterated_test);
+        g_signal_emit_by_name(priv->run_context, "start-iterated-test",
+                              iterated_test,
+                              priv->start_iterated_test->test_context);
+    }
+
+    if (priv->start_iterated_test->iterated_test)
+        DROP_TEST(priv);
+    if (priv->start_iterated_test->test_context)
+        DROP_TEST_CONTEXT(priv);
+    start_iterated_test_free(priv->start_iterated_test);
+    priv->start_iterated_test = NULL;
+}
+
 static void
 end_pass_assertion (CutStreamParser *parser, CutStreamParserPrivate *priv,
                     GMarkupParseContext *context,
@@ -1390,6 +1750,28 @@ end_test_result (CutStreamParser *parser, CutStreamParserPrivate *priv,
     priv->result = NULL;
 }
 
+static void
+end_complete_iterated_test (CutStreamParser *parser,
+                            CutStreamParserPrivate *priv,
+                            GMarkupParseContext *context,
+                            const gchar *element_name, GError **error)
+{
+    if (!priv->complete_iterated_test)
+        return;
+
+    if (priv->run_context)
+        g_signal_emit_by_name(priv->run_context, "complete-iterated-test",
+                              priv->complete_iterated_test->iterated_test,
+                              priv->complete_iterated_test->test_context);
+
+    if (priv->complete_iterated_test->iterated_test)
+        DROP_TEST(priv);
+    if (priv->complete_iterated_test->test_context)
+        DROP_TEST_CONTEXT(priv);
+    complete_iterated_test_free(priv->complete_iterated_test);
+    priv->complete_iterated_test = NULL;
+}
+
 static void
 end_complete_test (CutStreamParser *parser, CutStreamParserPrivate *priv,
                    GMarkupParseContext *context,
@@ -1411,6 +1793,24 @@ end_complete_test (CutStreamParser *parser, CutStreamParserPrivate *priv,
     priv->complete_test = NULL;
 }
 
+static void
+end_complete_test_iterator (CutStreamParser *parser,
+                            CutStreamParserPrivate *priv,
+                            GMarkupParseContext *context,
+                            const gchar *element_name, GError **error)
+{
+    CutTestIterator *test_iterator;
+
+    test_iterator = POP_TEST_ITERATOR(priv);
+    if (!test_iterator)
+        return;
+
+    if (priv->run_context)
+        g_signal_emit_by_name(priv->run_context,
+                              "complete-test-iterator", test_iterator);
+    g_object_unref(test_iterator);
+}
+
 static void
 end_test_case_result (CutStreamParser *parser, CutStreamParserPrivate *priv,
                       GMarkupParseContext *context,
@@ -1535,18 +1935,33 @@ end_element_handler (GMarkupParseContext *context,
       case IN_START_TEST_CASE:
         end_start_test_case(parser, priv, context, element_name, error);
         break;
+      case IN_READY_TEST_ITERATOR:
+        end_ready_test_iterator(parser, priv, context, element_name, error);
+        break;
+      case IN_START_TEST_ITERATOR:
+        end_start_test_iterator(parser, priv, context, element_name, error);
+        break;
       case IN_START_TEST:
         end_start_test(parser, priv, context, element_name, error);
         break;
+      case IN_START_ITERATED_TEST:
+        end_start_iterated_test(parser, priv, context, element_name, error);
+        break;
       case IN_PASS_ASSERTION:
         end_pass_assertion(parser, priv, context, element_name, error);
         break;
       case IN_TEST_RESULT:
         end_test_result(parser, priv, context, element_name, error);
         break;
+      case IN_COMPLETE_ITERATED_TEST:
+        end_complete_iterated_test(parser, priv, context, element_name, error);
+        break;
       case IN_COMPLETE_TEST:
         end_complete_test(parser, priv, context, element_name, error);
         break;
+      case IN_COMPLETE_TEST_ITERATOR:
+        end_complete_test_iterator(parser, priv, context, element_name, error);
+        break;
       case IN_TEST_CASE_RESULT:
         end_test_case_result(parser, priv, context, element_name, error);
         break;
@@ -1627,7 +2042,11 @@ target_test_object (CutStreamParserPrivate *priv, ParseState parent_state)
       case IN_TEST_CASE:
         target = CUT_TEST(PEEK_TEST_CASE(priv));
         break;
+      case IN_TEST_ITERATOR:
+        target = CUT_TEST(PEEK_TEST_ITERATOR(priv));
+        break;
       case IN_TEST:
+      case IN_ITERATED_TEST:
         target = PEEK_TEST(priv);
         break;
       default:
@@ -1826,6 +2245,30 @@ text_ready_test_case_n_tests (CutStreamParserPrivate *priv,
     }
 }
 
+static void
+text_ready_test_iterator_n_tests (CutStreamParserPrivate *priv,
+                                  GMarkupParseContext *context,
+                                  const gchar *text, gsize text_len,
+                                  GError **error)
+{
+    if (is_integer(text)) {
+        priv->ready_test_iterator->n_tests = atoi(text);
+    } else {
+        set_parse_error(context, error, "invalid # of tests: %s", text);
+    }
+}
+
+static void
+text_test_data_name (CutStreamParserPrivate *priv,
+                     GMarkupParseContext *context,
+                     const gchar *text, gsize text_len, GError **error)
+{
+    CutTestData *test_data;
+
+    test_data = PEEK_TEST_DATA(priv);
+    cut_test_data_set_name(test_data, text);
+}
+
 static void
 text_test_context_failed (CutStreamParserPrivate *priv,
                           GMarkupParseContext *context,
@@ -1917,6 +2360,12 @@ text_handler (GMarkupParseContext *context,
       case IN_READY_TEST_CASE_N_TESTS:
         text_ready_test_case_n_tests(priv, context, text, text_len, error);
         break;
+      case IN_READY_TEST_ITERATOR_N_TESTS:
+        text_ready_test_iterator_n_tests(priv, context, text, text_len, error);
+        break;
+      case IN_TEST_DATA_NAME:
+        text_test_data_name(priv, context, text, text_len, error);
+        break;
       case IN_TEST_CONTEXT_FAILED:
         text_test_context_failed(priv, context, text, text_len, error);
         break;
