@@ -36,13 +36,15 @@ typedef struct _CutTestContainerPrivate	CutTestContainerPrivate;
 struct _CutTestContainerPrivate
 {
     GList *tests;
+    gdouble elapsed;
 };
 
 G_DEFINE_ABSTRACT_TYPE (CutTestContainer, cut_test_container, CUT_TYPE_TEST)
 
 static void dispose        (GObject         *object);
 
-static gdouble  real_get_elapsed  (CutTest  *test);
+static gdouble  get_elapsed  (CutTest  *test);
+static void     set_elapsed  (CutTest  *test, gdouble elapsed);
 
 static void
 cut_test_container_class_init (CutTestContainerClass *klass)
@@ -55,7 +57,8 @@ cut_test_container_class_init (CutTestContainerClass *klass)
 
     gobject_class->dispose      = dispose;
 
-    test_class->get_elapsed = real_get_elapsed;
+    test_class->get_elapsed = get_elapsed;
+    test_class->set_elapsed = set_elapsed;
 
     g_type_class_add_private(gobject_class, sizeof(CutTestContainerPrivate));
 }
@@ -66,6 +69,7 @@ cut_test_container_init (CutTestContainer *container)
     CutTestContainerPrivate *priv = CUT_TEST_CONTAINER_GET_PRIVATE(container);
 
     priv->tests = NULL;
+    priv->elapsed = -1.0;
 }
 
 static void
@@ -100,7 +104,7 @@ cut_test_container_get_children (CutTestContainer *container)
 }
 
 static gdouble
-real_get_elapsed (CutTest *test)
+get_elapsed (CutTest *test)
 {
     gdouble result = 0.0;
     GList *child;
@@ -109,6 +113,9 @@ real_get_elapsed (CutTest *test)
     g_return_val_if_fail(CUT_IS_TEST_CONTAINER(test), FALSE);
 
     priv = CUT_TEST_CONTAINER_GET_PRIVATE(test);
+    if (!(priv->elapsed < 0.0))
+        return priv->elapsed;
+
     for (child = priv->tests; child; child = g_list_next(child)) {
         CutTest *test = child->data;
 
@@ -118,46 +125,17 @@ real_get_elapsed (CutTest *test)
     return result;
 }
 
-static GList *
-filter_to_regexs (gchar **filter)
+static void
+set_elapsed (CutTest *test, gdouble elapsed)
 {
-    GList *regexs = NULL;
+    g_return_if_fail(CUT_IS_TEST_CONTAINER(test));
 
-    for (; *filter; filter++) {
-        GRegex *regex;
-        gchar *pattern;
-
-        if (*filter[0] == '\0')
-            continue;
-
-        pattern = cut_utils_create_regex_pattern(*filter);
-        regex = g_regex_new(pattern, G_REGEX_EXTENDED, 0, NULL);
-        if (regex)
-            regexs = g_list_prepend(regexs, regex);
-        g_free(pattern);
-    }
-
-    return regexs;
-}
-
-static inline gboolean
-match (GList *regexs, const gchar *name)
-{
-    GList *node;
-
-    for (node = regexs; node; node = g_list_next(node)) {
-        GRegex *regex = node->data;
-
-        if (g_regex_match(regex, name, 0, NULL))
-            return TRUE;
-    }
-
-    return FALSE;
+    CUT_TEST_CONTAINER_GET_PRIVATE(test)->elapsed = elapsed;
 }
 
 GList *
 cut_test_container_filter_children (CutTestContainer *container,
-                                    gchar **filter)
+                                    const gchar **filter)
 {
     GList *original, *node, *regexs;
     GList *matched_tests = NULL;
@@ -168,14 +146,14 @@ cut_test_container_filter_children (CutTestContainer *container,
     if (!filter)
         return g_list_copy(original);
 
-    regexs = filter_to_regexs(filter);
+    regexs = cut_utils_filter_to_regexs(filter);
     if (!regexs)
         return g_list_copy(original);
 
     for (node = original; node; node = g_list_next(node)) {
         CutTest *test = node->data;
 
-        if (match(regexs, cut_test_get_name(test)))
+        if (cut_utils_filter_match(regexs, cut_test_get_name(test)))
             matched_tests = g_list_prepend(matched_tests, test);
     }
 
