@@ -53,7 +53,7 @@ void         cut_test_container_add_test     (CutTestContainer *container,
 GList       *cut_test_container_get_children (CutTestContainer *container);
 GList       *cut_test_container_filter_children
                                              (CutTestContainer *container,
-                                              gchar           **filter);
+                                              const gchar     **filter);
 
 G_END_DECLS
 
