@@ -35,7 +35,9 @@
 
 #include "cut-test-context.h"
 #include "cut-test-suite.h"
+#include "cut-test-iterator.h"
 #include "cut-test-result.h"
+#include "cut-test-data.h"
 #include "cut-process.h"
 #include "cut-utils.h"
 
@@ -57,6 +59,7 @@ struct _CutTestContextPrivate
 {
     CutTestSuite *test_suite;
     CutTestCase *test_case;
+    CutTestIterator *test_iterator;
     CutTest *test;
     gboolean failed;
     gboolean is_multi_thread;
@@ -65,8 +68,9 @@ struct _CutTestContextPrivate
     GList *taken_string_arrays;
     GList *taken_objects;
     GList *taken_errors;
-    gpointer user_data;
-    GDestroyNotify user_data_destroy_notify;
+    GList *taken_lists;
+    GList *current_data;
+    GList *data_list;
     GList *processes;
     gchar *fixture_data_dir;
     GHashTable *cached_fixture_data;
@@ -77,11 +81,43 @@ enum
     PROP_0,
     PROP_TEST_SUITE,
     PROP_TEST_CASE,
+    PROP_TEST_ITERATOR,
     PROP_TEST
 };
 
 G_DEFINE_TYPE (CutTestContext, cut_test_context, G_TYPE_OBJECT)
 
+typedef struct _TakenList TakenList;
+struct _TakenList
+{
+    GList *list;
+    CutDestroyFunction destroy_function;
+};
+
+static TakenList *
+taken_list_new (GList *list, CutDestroyFunction destroy_function)
+{
+    TakenList *taken_list;
+
+    taken_list = g_slice_new(TakenList);
+    taken_list->list = g_list_copy(list);
+    taken_list->destroy_function = destroy_function;
+    return taken_list;
+}
+
+static void
+taken_list_free (TakenList *taken_list)
+{
+    if (taken_list->destroy_function)
+        g_list_foreach(taken_list->list,
+                       (GFunc)taken_list->destroy_function,
+                       NULL);
+    g_list_free(taken_list->list);
+
+    g_slice_free(TakenList, taken_list);
+}
+
+
 static void dispose        (GObject         *object);
 static void set_property   (GObject         *object,
                             guint            prop_id,
@@ -92,6 +128,7 @@ static void get_property   (GObject         *object,
                             GValue          *value,
                             GParamSpec      *pspec);
 
+
 static void
 cut_test_context_class_init (CutTestContextClass *klass)
 {
@@ -118,6 +155,13 @@ cut_test_context_class_init (CutTestContextClass *klass)
                                G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY);
     g_object_class_install_property(gobject_class, PROP_TEST_CASE, spec);
 
+    spec = g_param_spec_object("test-iterator",
+                               "Test iterator",
+                               "The test iterator of the test context",
+                               CUT_TYPE_TEST_ITERATOR,
+                               G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY);
+    g_object_class_install_property(gobject_class, PROP_TEST_ITERATOR, spec);
+
     spec = g_param_spec_object("test",
                                "Test",
                                "The test of the test context",
@@ -135,6 +179,7 @@ cut_test_context_init (CutTestContext *context)
 
     priv->test_suite = NULL;
     priv->test_case = NULL;
+    priv->test_iterator = NULL;
     priv->test = NULL;
 
     priv->failed = FALSE;
@@ -145,9 +190,10 @@ cut_test_context_init (CutTestContext *context)
 
     priv->taken_objects = NULL;
     priv->taken_errors = NULL;
+    priv->taken_lists = NULL;
 
-    priv->user_data = NULL;
-    priv->user_data_destroy_notify = NULL;
+    priv->data_list = NULL;
+    priv->current_data = NULL;
 
     priv->processes = NULL;
 
@@ -156,6 +202,17 @@ cut_test_context_init (CutTestContext *context)
                                                       g_free, g_free);
 }
 
+static void
+free_data_list (CutTestContextPrivate *priv)
+{
+    if (priv->data_list) {
+        g_list_foreach(priv->data_list, (GFunc)g_object_unref, NULL);
+        g_list_free(priv->data_list);
+        priv->data_list = NULL;
+    }
+    priv->current_data = NULL;
+}
+
 static void
 dispose (GObject *object)
 {
@@ -171,6 +228,11 @@ dispose (GObject *object)
         priv->test_case = NULL;
     }
 
+    if (priv->test_iterator) {
+        g_object_unref(priv->test_iterator);
+        priv->test_iterator = NULL;
+    }
+
     if (priv->test) {
         g_object_unref(priv->test);
         priv->test = NULL;
@@ -182,9 +244,11 @@ dispose (GObject *object)
         priv->processes = NULL;
     }
 
-    g_list_foreach(priv->taken_strings, (GFunc)g_free, NULL);
-    g_list_free(priv->taken_strings);
-    priv->taken_strings = NULL;
+    if (priv->taken_strings) {
+        g_list_foreach(priv->taken_strings, (GFunc)g_free, NULL);
+        g_list_free(priv->taken_strings);
+        priv->taken_strings = NULL;
+    }
 
     if (priv->taken_string_arrays) {
         g_list_foreach(priv->taken_string_arrays, (GFunc)g_strfreev, NULL);
@@ -204,9 +268,13 @@ dispose (GObject *object)
         priv->taken_errors = NULL;
     }
 
-    if (priv->user_data && priv->user_data_destroy_notify)
-        priv->user_data_destroy_notify(priv->user_data);
-    priv->user_data = NULL;
+    if (priv->taken_lists) {
+        g_list_foreach(priv->taken_lists, (GFunc)taken_list_free, NULL);
+        g_list_free(priv->taken_lists);
+        priv->taken_lists = NULL;
+    }
+
+    free_data_list(priv);
 
     if (priv->fixture_data_dir) {
         g_free(priv->fixture_data_dir);
@@ -236,6 +304,9 @@ set_property (GObject      *object,
       case PROP_TEST_CASE:
         cut_test_context_set_test_case(context, g_value_get_object(value));
         break;
+      case PROP_TEST_ITERATOR:
+        cut_test_context_set_test_iterator(context, g_value_get_object(value));
+        break;
       case PROP_TEST:
         cut_test_context_set_test(context, g_value_get_object(value));
         break;
@@ -260,6 +331,9 @@ get_property (GObject    *object,
       case PROP_TEST_CASE:
         g_value_set_object(value, priv->test_case);
         break;
+      case PROP_TEST_ITERATOR:
+        g_value_set_object(value, priv->test_iterator);
+        break;
       case PROP_TEST:
         g_value_set_object(value, priv->test);
         break;
@@ -271,11 +345,12 @@ get_property (GObject    *object,
 
 CutTestContext *
 cut_test_context_new (CutTestSuite *test_suite, CutTestCase *test_case,
-                      CutTest *test)
+                      CutTestIterator *test_iterator, CutTest *test)
 {
     return g_object_new(CUT_TYPE_TEST_CONTEXT,
                         "test-suite", test_suite,
                         "test-case", test_case,
+                        "test-iterator", test_iterator,
                         "test", test,
                         NULL);
 }
@@ -283,7 +358,7 @@ cut_test_context_new (CutTestSuite *test_suite, CutTestCase *test_case,
 CutTestContext *
 cut_test_context_new_empty (void)
 {
-    return cut_test_context_new(NULL, NULL, NULL);
+    return cut_test_context_new(NULL, NULL, NULL, NULL);
 }
 
 CutTestSuite *
@@ -322,6 +397,25 @@ cut_test_context_set_test_case (CutTestContext *context, CutTestCase *test_case)
     priv->test_case = test_case;
 }
 
+CutTestIterator *
+cut_test_context_get_test_iterator (CutTestContext *context)
+{
+    return CUT_TEST_CONTEXT_GET_PRIVATE(context)->test_iterator;
+}
+
+void
+cut_test_context_set_test_iterator (CutTestContext *context,
+                                    CutTestIterator *test_iterator)
+{
+    CutTestContextPrivate *priv = CUT_TEST_CONTEXT_GET_PRIVATE(context);
+
+    if (priv->test_iterator)
+        g_object_unref(priv->test_iterator);
+    if (test_iterator)
+        g_object_ref(test_iterator);
+    priv->test_iterator = test_iterator;
+}
+
 CutTest *
 cut_test_context_get_test (CutTestContext *context)
 {
@@ -340,23 +434,83 @@ cut_test_context_set_test (CutTestContext *context, CutTest *test)
     priv->test = test;
 }
 
-gpointer
-cut_test_context_get_user_data (CutTestContext *context)
+void
+cut_test_context_add_data (CutTestContext *context, const gchar *first_data_name,
+                           ...)
 {
-    return CUT_TEST_CONTEXT_GET_PRIVATE(context)->user_data;
+    CutTestContextPrivate *priv;
+    const gchar *name;
+    va_list args;
+
+    priv = CUT_TEST_CONTEXT_GET_PRIVATE(context);
+
+    name = first_data_name;
+    va_start(args, first_data_name);
+    while (name) {
+        CutTestData *test_data;
+        gpointer data;
+        CutDestroyFunction destroy_function;
+
+        data = va_arg(args, gpointer);
+        destroy_function = va_arg(args, CutDestroyFunction);
+        test_data = cut_test_data_new(name, data, destroy_function);
+        priv->data_list = g_list_prepend(priv->data_list, test_data);
+        if (!priv->current_data)
+            priv->current_data = priv->data_list;
+
+        name = va_arg(args, gchar *);
+    }
+    va_end(args);
 }
 
 void
-cut_test_context_set_user_data (CutTestContext *context, gpointer user_data,
-                                GDestroyNotify notify)
+cut_test_context_set_data (CutTestContext *context, CutTestData *test_data)
 {
-    CutTestContextPrivate *priv = CUT_TEST_CONTEXT_GET_PRIVATE(context);
+    CutTestContextPrivate *priv;
 
-    if (priv->user_data && priv->user_data_destroy_notify)
-        priv->user_data_destroy_notify(priv->user_data);
+    priv = CUT_TEST_CONTEXT_GET_PRIVATE(context);
 
-    priv->user_data = user_data;
-    priv->user_data_destroy_notify = notify;
+    free_data_list(priv);
+
+    if (test_data) {
+        g_object_ref(test_data);
+        priv->data_list = g_list_prepend(priv->data_list, test_data);
+        priv->current_data = priv->data_list;
+    }
+}
+
+void
+cut_test_context_shift_data (CutTestContext *context)
+{
+    CutTestContextPrivate *priv;
+
+    priv = CUT_TEST_CONTEXT_GET_PRIVATE(context);
+
+    if (priv->current_data)
+        priv->current_data = g_list_previous(priv->current_data);
+}
+
+gboolean
+cut_test_context_have_data (CutTestContext *context)
+{
+    return CUT_TEST_CONTEXT_GET_PRIVATE(context)->current_data != NULL;
+}
+
+CutTestData *
+cut_test_context_get_current_data (CutTestContext *context)
+{
+    CutTestContextPrivate *priv;
+
+    priv = CUT_TEST_CONTEXT_GET_PRIVATE(context);
+    g_return_val_if_fail(priv->current_data != NULL, NULL);
+
+    return priv->current_data->data;
+}
+
+guint
+cut_test_context_get_n_data (CutTestContext *context)
+{
+    return g_list_length(CUT_TEST_CONTEXT_GET_PRIVATE(context)->data_list);
 }
 
 void
@@ -367,6 +521,12 @@ cut_test_context_set_jump (CutTestContext *context, jmp_buf *buffer)
     priv->jump_buffer = buffer;
 }
 
+jmp_buf *
+cut_test_context_get_jump (CutTestContext *context)
+{
+    return CUT_TEST_CONTEXT_GET_PRIVATE(context)->jump_buffer;
+}
+
 void
 cut_test_context_long_jump (CutTestContext *context)
 {
@@ -416,6 +576,9 @@ cut_test_context_emit_signal (CutTestContext *context,
         cut_test_result_set_elapsed(result, cut_test_get_elapsed(priv->test));
         g_signal_emit_by_name(priv->test, status_signal_name,
                               context, result);
+    } else if (priv->test_iterator) {
+        g_signal_emit_by_name(priv->test_iterator, status_signal_name,
+                              context, result);
     } else if (priv->test_case) {
         g_signal_emit_by_name(priv->test_case, status_signal_name,
                               context, result);
@@ -431,12 +594,14 @@ cut_test_context_register_result (CutTestContext *context,
                                   const gchar *message,
                                   ...)
 {
-    CutTestContextPrivate *priv = CUT_TEST_CONTEXT_GET_PRIVATE(context);
+    CutTestContextPrivate *priv;
     CutTestResult *result;
+    CutTestData *test_data = NULL;
     const gchar *system_message;
     gchar *user_message = NULL, *user_message_format;
     va_list args;
 
+    priv = CUT_TEST_CONTEXT_GET_PRIVATE(context);
     if (cut_test_result_status_is_critical(status))
         priv->failed = TRUE;
 
@@ -448,8 +613,12 @@ cut_test_context_register_result (CutTestContext *context,
     }
     va_end(args);
 
+    if (priv->current_data)
+        test_data = priv->current_data->data;
     result = cut_test_result_new(status,
-                                 priv->test, priv->test_case, priv->test_suite,
+                                 priv->test, priv->test_iterator,
+                                 priv->test_case, priv->test_suite,
+                                 test_data,
                                  user_message, system_message,
                                  function_name, filename, line);
     if (user_message)
@@ -555,6 +724,21 @@ cut_test_context_take_g_error (CutTestContext *context, GError *error)
     return taken_error;
 }
 
+const GList *
+cut_test_context_take_g_list (CutTestContext *context, GList *list,
+                              CutDestroyFunction destroy_function)
+{
+    CutTestContextPrivate *priv;
+    TakenList *taken_list;
+
+    priv = CUT_TEST_CONTEXT_GET_PRIVATE(context);
+    taken_list = taken_list_new(list, destroy_function);
+    priv->taken_lists = g_list_prepend(priv->taken_lists, taken_list);
+    g_list_free(list);
+
+    return taken_list->list;
+}
+
 int
 cut_test_context_trap_fork (CutTestContext *context,
                             const gchar *function_name,
@@ -698,8 +882,14 @@ cut_test_context_to_xml_string (CutTestContext *context, GString *string,
         cut_test_to_xml_string(CUT_TEST(priv->test_suite), string, indent + 2);
     if (priv->test_case)
         cut_test_to_xml_string(CUT_TEST(priv->test_case), string, indent + 2);
+    if (priv->test_iterator)
+        cut_test_to_xml_string(CUT_TEST(priv->test_iterator),
+                               string, indent + 2);
     if (priv->test)
         cut_test_to_xml_string(priv->test, string, indent + 2);
+    if (priv->current_data)
+        cut_test_data_to_xml_string(priv->current_data->data,
+                                    string, indent + 2);
 
     cut_utils_append_xml_element_with_boolean_value(string, indent + 2,
                                                     "failed", priv->failed);
