@@ -1,6 +1,6 @@
 /* -*- Mode: C; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
- *  Copyright (C) 2007  Kouhei Sutou <kou@cozmixng.org>
+ *  Copyright (C) 2007-2008  Kouhei Sutou <kou@cozmixng.org>
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -28,6 +28,7 @@
 #include "cut-test-result.h"
 #include "cut-enum-types.h"
 #include "cut-test.h"
+#include "cut-test-iterator.h"
 #include "cut-test-case.h"
 #include "cut-test-suite.h"
 #include "cut-stream-parser.h"
@@ -40,8 +41,11 @@ struct _CutTestResultPrivate
 {
     CutTestResultStatus status;
     CutTest *test;
+    CutTestIterator *test_iterator;
     CutTestCase *test_case;
     CutTestSuite *test_suite;
+    CutTestData *test_data;
+    gchar *test_name;
     gchar *message;
     gchar *user_message;
     gchar *system_message;
@@ -56,8 +60,10 @@ enum
     PROP_0,
     PROP_STATUS,
     PROP_TEST,
+    PROP_TEST_ITERATOR,
     PROP_TEST_CASE,
     PROP_TEST_SUITE,
+    PROP_TEST_DATA,
     PROP_USER_MESSAGE,
     PROP_SYSTEM_MESSAGE,
     PROP_FUNCTION_NAME,
@@ -106,6 +112,13 @@ cut_test_result_class_init (CutTestResultClass *klass)
                                G_PARAM_READWRITE);
     g_object_class_install_property(gobject_class, PROP_TEST, spec);
 
+    spec = g_param_spec_object("test-iterator",
+                               "CutTestIterator object",
+                               "A CutTestIterator object",
+                               CUT_TYPE_TEST_ITERATOR,
+                               G_PARAM_READWRITE);
+    g_object_class_install_property(gobject_class, PROP_TEST_ITERATOR, spec);
+
     spec = g_param_spec_object("test-case",
                                "CutTestCase object",
                                "A CutTestCase object",
@@ -120,6 +133,13 @@ cut_test_result_class_init (CutTestResultClass *klass)
                                G_PARAM_READWRITE);
     g_object_class_install_property(gobject_class, PROP_TEST_SUITE, spec);
 
+    spec = g_param_spec_object("test-data",
+                               "CutTestData object",
+                               "A CutTestData object",
+                               CUT_TYPE_TEST_DATA,
+                               G_PARAM_READWRITE);
+    g_object_class_install_property(gobject_class, PROP_TEST_DATA, spec);
+
     spec = g_param_spec_string("user-message",
                                "User Message",
                                "The message from user of the result",
@@ -172,8 +192,11 @@ cut_test_result_init (CutTestResult *result)
 
     priv->status = CUT_TEST_RESULT_SUCCESS;
     priv->test = NULL;
+    priv->test_iterator = NULL;
     priv->test_case = NULL;
     priv->test_suite = NULL;
+    priv->test_data = NULL;
+    priv->test_name = NULL;
     priv->message = NULL;
     priv->user_message = NULL;
     priv->system_message = NULL;
@@ -193,6 +216,11 @@ dispose (GObject *object)
         priv->test = NULL;
     }
 
+    if (priv->test_iterator) {
+        g_object_unref(priv->test_iterator);
+        priv->test_iterator = NULL;
+    }
+
     if (priv->test_case) {
         g_object_unref(priv->test_case);
         priv->test_case = NULL;
@@ -203,6 +231,16 @@ dispose (GObject *object)
         priv->test_suite = NULL;
     }
 
+    if (priv->test_data) {
+        g_object_unref(priv->test_data);
+        priv->test_data = NULL;
+    }
+
+    if (priv->test_name) {
+        g_free(priv->test_name);
+        priv->test_name = NULL;
+    }
+
     if (priv->message) {
         g_free(priv->message);
         priv->message = NULL;
@@ -247,6 +285,10 @@ set_property (GObject      *object,
         cut_test_result_set_test(CUT_TEST_RESULT(object),
                                  g_value_get_object(value));
         break;
+      case PROP_TEST_ITERATOR:
+        cut_test_result_set_test_iterator(CUT_TEST_RESULT(object),
+                                          g_value_get_object(value));
+        break;
       case PROP_TEST_CASE:
         cut_test_result_set_test_case(CUT_TEST_RESULT(object),
                                       g_value_get_object(value));
@@ -255,6 +297,10 @@ set_property (GObject      *object,
         cut_test_result_set_test_suite(CUT_TEST_RESULT(object),
                                        g_value_get_object(value));
         break;
+      case PROP_TEST_DATA:
+        cut_test_result_set_test_data(CUT_TEST_RESULT(object),
+                                      g_value_get_object(value));
+        break;
       case PROP_USER_MESSAGE:
         cut_test_result_set_user_message(CUT_TEST_RESULT(object),
                                          g_value_get_string(value));
@@ -301,12 +347,18 @@ get_property (GObject    *object,
       case PROP_TEST:
         g_value_set_object(value, G_OBJECT(priv->test));
         break;
+      case PROP_TEST_ITERATOR:
+        g_value_set_object(value, G_OBJECT(priv->test_iterator));
+        break;
       case PROP_TEST_CASE:
         g_value_set_object(value, G_OBJECT(priv->test_case));
         break;
       case PROP_TEST_SUITE:
         g_value_set_object(value, G_OBJECT(priv->test_suite));
         break;
+      case PROP_TEST_DATA:
+        g_value_set_object(value, G_OBJECT(priv->test_data));
+        break;
       case PROP_USER_MESSAGE:
         g_value_set_string(value, priv->user_message);
         break;
@@ -334,8 +386,10 @@ get_property (GObject    *object,
 CutTestResult *
 cut_test_result_new (CutTestResultStatus status,
                      CutTest *test,
+                     CutTestIterator *test_iterator,
                      CutTestCase *test_case,
                      CutTestSuite *test_suite,
+                     CutTestData *test_data,
                      const gchar *user_message,
                      const gchar *system_message,
                      const gchar *function_name,
@@ -345,8 +399,10 @@ cut_test_result_new (CutTestResultStatus status,
     return g_object_new(CUT_TYPE_TEST_RESULT,
                         "status", status,
                         "test", test,
+                        "test-iterator", test_iterator,
                         "test-case", test_case,
                         "test-suite", test_suite,
+                        "test-data", test_data,
                         "user-message", user_message,
                         "system-message", system_message,
                         "function-name", function_name,
@@ -359,7 +415,7 @@ CutTestResult *
 cut_test_result_new_empty (void)
 {
     return cut_test_result_new(CUT_TEST_RESULT_SUCCESS,
-                               NULL, NULL, NULL,
+                               NULL, NULL, NULL, NULL, NULL,
                                NULL, NULL,
                                NULL, NULL, 0);
 }
@@ -429,6 +485,12 @@ cut_test_result_get_test (CutTestResult *result)
     return CUT_TEST_RESULT_GET_PRIVATE(result)->test;
 }
 
+CutTestIterator *
+cut_test_result_get_test_iterator (CutTestResult *result)
+{
+    return CUT_TEST_RESULT_GET_PRIVATE(result)->test_iterator;
+}
+
 CutTestCase *
 cut_test_result_get_test_case (CutTestResult *result)
 {
@@ -437,11 +499,43 @@ cut_test_result_get_test_case (CutTestResult *result)
 
 const gchar *
 cut_test_result_get_test_name (CutTestResult *result)
+{
+    CutTestResultPrivate *priv;
+
+    priv = CUT_TEST_RESULT_GET_PRIVATE(result);
+
+    if (priv->test_name) {
+        g_free(priv->test_name);
+        priv->test_name = NULL;
+    }
+
+    if (priv->test) {
+        const gchar *name;
+        const gchar *data_name = NULL;
+
+        name = cut_test_get_name(priv->test);
+        if (priv->test_data)
+            data_name = cut_test_data_get_name(priv->test_data);
+
+        if (name && data_name) {
+            priv->test_name = g_strconcat(name, " (", data_name, ")", NULL);
+        } else if (name) {
+            priv->test_name = g_strdup(name);
+        } else if (data_name) {
+            priv->test_name = g_strconcat(" (", data_name, ")", NULL);
+        }
+    }
+
+    return priv->test_name;
+}
+
+const gchar *
+cut_test_result_get_test_iterator_name (CutTestResult *result)
 {
     CutTestResultPrivate *priv = CUT_TEST_RESULT_GET_PRIVATE(result);
 
-    if (priv->test)
-        return cut_test_get_name(priv->test);
+    if (priv->test_iterator)
+        return cut_test_get_name(CUT_TEST(priv->test_iterator));
     return NULL;
 }
 
@@ -471,6 +565,12 @@ cut_test_result_get_test_suite_name (CutTestResult *result)
     return NULL;
 }
 
+CutTestData *
+cut_test_result_get_test_data (CutTestResult *result)
+{
+    return CUT_TEST_RESULT_GET_PRIVATE(result)->test_data;
+}
+
 const gchar *
 cut_test_result_get_user_message (CutTestResult *result)
 {
@@ -643,6 +743,7 @@ cut_test_result_to_xml_string (CutTestResult *result, GString *string,
                                guint indent)
 {
     CutTestCase *test_case;
+    CutTestIterator *test_iterator;
     CutTest *test;
 
     cut_utils_append_indent(string, indent);
@@ -651,6 +752,9 @@ cut_test_result_to_xml_string (CutTestResult *result, GString *string,
     test_case = cut_test_result_get_test_case(result);
     if (test_case)
         cut_test_to_xml_string(CUT_TEST(test_case), string, indent + 2);
+    test_iterator = cut_test_result_get_test_iterator(result);
+    if (test_iterator)
+        cut_test_to_xml_string(CUT_TEST(test_iterator), string, indent + 2);
     test = cut_test_result_get_test(result);
     if (test)
         cut_test_to_xml_string(test, string, indent + 2);
@@ -684,7 +788,7 @@ cut_test_result_status_to_signal_name (CutTestResultStatus status)
       case CUT_TEST_RESULT_ERROR:
         signal_name = "error";
         break;
-      case CUT_TEST_RESULT_INVALID:
+      default:
         signal_name = "invalid status";
         break;
     }
@@ -717,6 +821,20 @@ cut_test_result_set_test (CutTestResult *result, CutTest *test)
         priv->test = g_object_ref(test);
 }
 
+void
+cut_test_result_set_test_iterator (CutTestResult *result,
+                                   CutTestIterator *test_iterator)
+{
+    CutTestResultPrivate *priv = CUT_TEST_RESULT_GET_PRIVATE(result);
+
+    if (priv->test_iterator) {
+        g_object_unref(priv->test_iterator);
+        priv->test_iterator = NULL;
+    }
+    if (test_iterator)
+        priv->test_iterator = g_object_ref(test_iterator);
+}
+
 void
 cut_test_result_set_test_case (CutTestResult *result, CutTestCase *test_case)
 {
@@ -743,6 +861,19 @@ cut_test_result_set_test_suite (CutTestResult *result, CutTestSuite *test_suite)
         priv->test_suite = g_object_ref(test_suite);
 }
 
+void
+cut_test_result_set_test_data (CutTestResult *result, CutTestData *test_data)
+{
+    CutTestResultPrivate *priv = CUT_TEST_RESULT_GET_PRIVATE(result);
+
+    if (priv->test_data) {
+        g_object_unref(priv->test_data);
+        priv->test_data = NULL;
+    }
+    if (test_data)
+        priv->test_data = g_object_ref(test_data);
+}
+
 void
 cut_test_result_set_user_message (CutTestResult *result,
                                   const gchar *user_message)
