@@ -1,6 +1,6 @@
 /* -*- Mode: C; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
- *  Copyright (C) 2007  Kouhei Sutou <kou@cozmixng.org>
+ *  Copyright (C) 2007-2008  Kouhei Sutou <kou@cozmixng.org>
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -38,7 +38,9 @@ typedef struct _CutTestPrivate	CutTestPrivate;
 struct _CutTestPrivate
 {
     gchar *name;
+    gchar *full_name;
     gchar *element_name;
+    CutTestData *test_data;
     CutTestFunction test_function;
     GTimer *timer;
     gdouble elapsed;
@@ -84,6 +86,18 @@ static void get_property   (GObject         *object,
 
 static gdouble      get_elapsed  (CutTest  *test);
 static void         set_elapsed  (CutTest  *test, gdouble elapsed);
+static gboolean     run          (CutTest        *test,
+                                  CutTestContext *test_context,
+                                  CutRunContext  *run_context);
+static void         prepare      (CutTest        *test,
+                                  CutTestContext *test_context,
+                                  CutRunContext  *run_context);
+static gboolean     is_available (CutTest        *test,
+                                  CutTestContext *test_context,
+                                  CutRunContext  *run_context);
+static void         invoke       (CutTest        *test,
+                                  CutTestContext *test_context,
+                                  CutRunContext  *run_context);
 
 static void
 cut_test_class_init (CutTestClass *klass)
@@ -99,6 +113,10 @@ cut_test_class_init (CutTestClass *klass)
 
     klass->get_elapsed = get_elapsed;
     klass->set_elapsed = set_elapsed;
+    klass->run = run;
+    klass->prepare = prepare;
+    klass->is_available = is_available;
+    klass->invoke = invoke;
 
     spec = g_param_spec_string("name",
                                "Test name",
@@ -224,11 +242,24 @@ cut_test_init (CutTest *test)
 {
     CutTestPrivate *priv = CUT_TEST_GET_PRIVATE(test);
 
+    priv->full_name = NULL;
+
     priv->test_function = NULL;
     priv->timer = NULL;
     priv->elapsed = -1.0;
     priv->attributes = g_hash_table_new_full(g_str_hash, g_str_equal,
                                              g_free, g_free);
+
+    priv->test_data = NULL;
+}
+
+static void
+free_full_name (CutTestPrivate *priv)
+{
+    if (priv->full_name) {
+        g_free(priv->full_name);
+        priv->full_name = NULL;
+    }
 }
 
 static void
@@ -258,6 +289,13 @@ dispose (GObject *object)
         priv->attributes = NULL;
     }
 
+    if (priv->test_data) {
+        g_object_unref(priv->test_data);
+        priv->test_data = NULL;
+    }
+
+    free_full_name(priv);
+
     G_OBJECT_CLASS(cut_test_parent_class)->dispose(object);
 }
 
@@ -329,17 +367,40 @@ cut_test_new_empty (void)
     return cut_test_new(NULL, NULL);
 }
 
-gboolean
-cut_test_run (CutTest *test, CutTestContext *test_context, CutRunContext *run_context)
+static void
+prepare (CutTest *test, CutTestContext *test_context, CutRunContext *run_context)
 {
-    CutTestPrivate *priv = CUT_TEST_GET_PRIVATE(test);
+    cut_run_context_prepare_test(run_context, test);
+}
+
+static gboolean
+is_available (CutTest *test, CutTestContext *test_context,
+              CutRunContext *run_context)
+{
+    return CUT_TEST_GET_PRIVATE(test)->test_function != NULL;
+}
+
+static void
+invoke (CutTest *test, CutTestContext *test_context, CutRunContext *run_context)
+{
+    CUT_TEST_GET_PRIVATE(test)->test_function();
+}
+
+static gboolean
+run (CutTest *test, CutTestContext *test_context, CutRunContext *run_context)
+{
+    CutTestClass *klass;
+    CutTestPrivate *priv;
     gboolean success = TRUE;
     jmp_buf jump_buffer;
 
-    if (!priv->test_function)
+    priv = CUT_TEST_GET_PRIVATE(test);
+    klass = CUT_TEST_GET_CLASS(test);
+
+    if (!klass->is_available(test, test_context, run_context))
         return FALSE;
 
-    cut_run_context_prepare_test(run_context, test);
+    klass->prepare(test, test_context, run_context);
 
     g_signal_emit_by_name(test, "start");
 
@@ -350,17 +411,24 @@ cut_test_run (CutTest *test, CutTestContext *test_context, CutRunContext *run_co
         } else {
             priv->timer = g_timer_new();
         }
-        priv->test_function();
+        klass->invoke(test, test_context, run_context);
     }
     g_timer_stop(priv->timer);
 
     success = !cut_test_context_is_failed(test_context);
     if (success) {
+        CutTestCase *test_case;
+        CutTestIterator *test_iterator;
+        CutTestData *test_data = NULL;
         CutTestResult *result;
+
+        test_case = cut_test_context_get_test_case(test_context);
+        test_iterator = cut_test_context_get_test_iterator(test_context);
+        if (cut_test_context_have_data(test_context))
+            test_data = cut_test_context_get_current_data(test_context);
         result = cut_test_result_new(CUT_TEST_RESULT_SUCCESS,
-                                     test,
-                                     cut_test_context_get_test_case(test_context),
-                                     NULL,
+                                     test, test_iterator, test_case,
+                                     NULL, test_data,
                                      NULL, NULL,
                                      NULL, NULL, 0);
         cut_test_result_set_elapsed(result, cut_test_get_elapsed(test));
@@ -373,6 +441,13 @@ cut_test_run (CutTest *test, CutTestContext *test_context, CutRunContext *run_co
     return success;
 }
 
+gboolean
+cut_test_run (CutTest *test, CutTestContext *test_context,
+              CutRunContext *run_context)
+{
+    return CUT_TEST_GET_CLASS(test)->run(test, test_context, run_context);
+}
+
 const gchar *
 cut_test_get_name (CutTest *test)
 {
@@ -388,7 +463,9 @@ cut_test_set_name (CutTest *test, const gchar *name)
         g_free(priv->name);
         priv->name = NULL;
     }
-    
+
+    free_full_name(priv);
+
     if (name)
         priv->name = g_strdup(name);
 }
