@@ -23,7 +23,6 @@
 #include <glib-object.h>
 
 #include <cutter/cut-private.h>
-#include <cutter/cut-assertions.h>
 #include <cutter/cut-test-context.h>
 
 G_BEGIN_DECLS
@@ -40,6 +39,7 @@ typedef struct _CutTestClass    CutTestClass;
 typedef struct _CutTestResultClass    CutTestResultClass;
 
 typedef void    (*CutTestFunction)     (void);
+typedef void    (*CutDataSetupFunction)(void);
 typedef void    (*CutSetupFunction)    (void);
 typedef void    (*CutTeardownFunction) (void);
 typedef CutTestContext *(*CutGetCurrentTestContextFunction) (void);
@@ -81,6 +81,19 @@ struct _CutTestClass
 
     gdouble      (*get_elapsed)  (CutTest *test);
     void         (*set_elapsed)  (CutTest *test, gdouble elapsed);
+
+    gboolean     (*run)          (CutTest        *test,
+                                  CutTestContext *test_context,
+                                  CutRunContext  *run_context);
+    void         (*prepare)      (CutTest        *test,
+                                  CutTestContext *test_context,
+                                  CutRunContext  *run_context);
+    gboolean     (*is_available) (CutTest        *test,
+                                  CutTestContext *test_context,
+                                  CutRunContext  *run_context);
+    void         (*invoke)       (CutTest        *test,
+                                  CutTestContext *test_context,
+                                  CutRunContext  *run_context);
 };
 
 GType        cut_test_get_type  (void) G_GNUC_CONST;
@@ -96,6 +109,8 @@ void         cut_test_stop_timer          (CutTest     *test);
 const gchar *cut_test_get_name            (CutTest     *test);
 void         cut_test_set_name            (CutTest     *test,
                                            const gchar *name);
+CutDataSetupFunction cut_test_get_data_setup_function(CutTest *test);
+const gchar *cut_test_get_full_name       (CutTest     *test);
 const gchar *cut_test_get_description     (CutTest     *test);
 gdouble      cut_test_get_elapsed         (CutTest     *test);
 void         cut_test_set_elapsed         (CutTest     *test,
