@@ -24,12 +24,17 @@
 #include <glib.h>
 #include <glib/gi18n-lib.h>
 
+#include "cut-utils.h"
 #include "cut-ui-factory-builder.h"
 #include "cut-module-factory.h"
 #include "cut-module-factory-utils.h"
 
 static const gchar *ui_name = NULL;
 static CutUIFactoryBuilder *the_builder = NULL;
+#ifdef G_OS_WIN32
+static gchar *win32_ui_factory_module_dir = NULL;
+#endif
+
 
 static GObject *constructor  (GType                  type,
                               guint                  n_props,
@@ -82,8 +87,16 @@ cut_ui_factory_builder_init (CutUIFactoryBuilder *builder)
     const gchar *dir;
 
     dir = g_getenv("CUT_UI_FACTORY_MODULE_DIR");
-    if (!dir)
+    if (!dir) {
+#ifdef G_OS_WIN32
+        if (!win32_ui_factory_module_dir)
+            win32_ui_factory_module_dir =
+                cut_win32_build_factory_module_dir_name("ui");
+        dir = win32_ui_factory_module_dir;
+#else
         dir = UI_FACTORY_MODULEDIR;
+#endif
+    }
 
     g_object_set(G_OBJECT(builder),
                  "module-dir", dir,
