@@ -1,6 +1,6 @@
 /* -*- Mode: C; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
- *  Copyright (C) 2007  Kouhei Sutou <kou@cozmixng.org>
+ *  Copyright (C) 2007-2008  Kouhei Sutou <kou@cozmixng.org>
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -172,6 +172,88 @@ void startup(void);
  */
 void shutdown(void);
 
+/**
+ * cut_add_data:
+ * @first_data_name: The first data name.
+ * @...: The data and destroy function of the first data,
+ *       followed optionally by more
+ *       name/data/destroy_function(#CutDestroyFunction)
+ *       triples.
+ *
+ * Adds data to use data driven test.
+ *
+ * e.g.:
+ * |[
+ * #include <cutter.h>
+ *
+ * void data_translate (void);
+ * void test_translate (const void *data);
+ *
+ * static const char*
+ * translate (int input)
+ * {
+ *    switch(input) {
+ *    case 1:
+ *        return "first";
+ *    case 111:
+ *        return "a hundred eleven";
+ *    default:
+ *        return "unsupported";
+ *    }
+ * }
+ *
+ * typedef struct _TranslateTestData
+ * {
+ *     char *translated;
+ *     int input;
+ * } TranslateTestData;
+ *
+ * static TranslateTestData *
+ * translate_test_data_new (char *translated, int input)
+ * {
+ *     TranslateTestData *data;
+ *
+ *     data = malloc(sizeof(TranslateTestData));
+ *     data->translated = strdup(translated);
+ *     data->input = input;
+ *
+ *     return data;
+ * }
+ *
+ * static void
+ * translate_test_data_free (TranslateTestData *data)
+ * {
+ *     free(data->translated);
+ *     free(data);
+ * }
+ *
+ * void
+ * data_translate(void)
+ * {
+ *     cut_add_data("simple data",
+ *                  translate_test_data_new("first", 1),
+ *                  translate_test_data_free,
+ *                  "complex data",
+ *                  translate_test_data_new("a hundred eleven", 111),
+ *                  translate_test_data_free);
+ * }
+ *
+ * void
+ * test_translate(const void *data)
+ * {
+ *      const TranslateTestData *test_data = data;
+ *
+ *      cut_assert_equal_string(test_data->translated,
+ *                              translate(test_data->input));
+ * }
+ * ]|
+ *
+ * Since: 1.0.3
+ */
+#define cut_add_data(first_data_name, ...)                      \
+    cut_test_context_add_data(get_current_test_context(),       \
+                              first_data_name, ## __VA_ARGS__,  \
+                              NULL)
 
 #ifdef __cplusplus
 }
