@@ -1,9 +1,13 @@
 require "English"
 
 require "erb"
+require "optparse"
 require "rd/rdvisitor"
 require "rd/version"
 
+require "gettext"
+require "gettext/poparser"
+
 module RD
   class RD2RefEntryVisitor < RDVisitor
     include ERB::Util
@@ -12,8 +16,15 @@ module RD
     SYSTEM_VERSION = "0.0.1"
     VERSION = Version.new_from_version_string(SYSTEM_NAME, SYSTEM_VERSION)
 
-    def self.version
-      VERSION
+    @@po = nil
+    class << self
+      def version
+        VERSION
+      end
+
+      def po=(po)
+        @@po = po
+      end
     end
 
     # must-have constants
@@ -24,6 +35,7 @@ module RD
 
     def initialize
       super
+      @translate_data = nil
     end
 
     def apply_to_DocumentElement(element, contents)
@@ -40,7 +52,7 @@ module RD
 
     def apply_to_Headline(element, title)
       if element.level == 1
-        @title, @purpose = title.join.split(/\B---\B/, 2)
+        @title, @purpose = title.join.split(/\s*\B---\B\s*/, 2)
       end
       [:headline, element.level - 1, title]
     end
@@ -53,14 +65,32 @@ module RD
       tag("programlisting", {}, contents.join("").chomp)
     end
 
-    def apply_to_Reference_with_URL(element, contents)
-      if /\Ahttp:\/\/cutter\.sf\.net\/reference\// =~ element.label.url
-        url = File.basename($POSTMATCH)
-        label = url
+    def apply_to_Reference_with_RDLabel(element, contents)
+      raise "label with filename is unsupported" if element.label.filename
+      url = element.label.element_label
+      label = contents.join("").chomp
+      label = url if label.empty?
+      case url
+      when /\.html$/
+        if /\(\)$/ =~ label
+          anchor = $PREMATCH.gsub(/_/, "-")
+          url = "#{url}\##{anchor}"
+        end
+      when /\.html#[a-zA-Z\-_]+$/
       else
-        url = element.label.url
-        label = contents.join("").chomp
+        url = remove_lang_suffix(url.downcase) + ".html"
       end
+      label = remove_lang_suffix(label)
+      tag("ulink", {:url => url}, label)
+    end
+
+    def apply_to_Reference_with_URL(element, contents)
+      url = element.label.url
+      label = contents.join("").chomp
+      if /\Ahttp:\/\/cutter\.(?:sf|sourceforge)\.net\/reference\// =~ url
+        url = File.basename($POSTMATCH)
+      end
+      url = label if label.empty?
       tag("ulink", {:url => url}, label)
     end
 
@@ -103,6 +133,23 @@ module RD
     end
 
     private
+    def _(msgstr)
+      translate_data[msgstr] || msgstr
+    end
+
+    def translate_data
+      @translate_data ||= make_translate_data
+    end
+
+    def make_translate_data
+      data = MOFile.new
+      if @@po
+        parser = GetText::PoParser.new
+        parser.parse(File.read(@@po), data)
+      end
+      data
+    end
+
     def xml_decl
       "<?xml version=\"1.0\" encoding=\"utf-8\"?>"
     end
@@ -143,12 +190,17 @@ module RD
 
     def ref_meta
       tag("refmeta", {},
-          tag("refentrytitle", {}, @title),
-          tag("refmiscinfo", {}, h("Cutter Library")))
+          tag("refentrytitle",
+              {
+                "role" => "top_of_page",
+                "id" => "#{ref_entry_id}.top_of_page",
+              },
+              @title),
+          tag("refmiscinfo", {}, h(_("CUTTER Library"))))
     end
 
     def ref_name_div
-      contents = tag("refname", {}, @title)
+      contents = [tag("refname", {}, @title)]
       contents << tag("refpurpose", {}, @purpose) if @purpose
       tag("refnamediv", {}, *contents)
     end
@@ -191,10 +243,9 @@ module RD
         unless sub_section_contents.empty?
           raise "!?" unless section_contents.last[0] == level
           _, contents = section_contents.pop
-          tagged_contents = tag("refsect#{level}", {},
-                                *(contents + sub_section_contents))
           if level > 0
-            contents = tagged_contents
+            contents = tag("refsect#{level}", {},
+                           *(contents + sub_section_contents))
           else
             contents = sub_section_contents.join("\n\n")
           end
@@ -207,7 +258,16 @@ module RD
     def consist_of_one_textblock?(listitem)
       listitem.children.size == 1 and listitem.children[0].is_a?(TextBlock)
     end
+
+    def remove_lang_suffix(string)
+      string.sub(/\.[a-z]{2}$/, "")
+    end
   end
 end
 
 $Visitor_Class = RD::RD2RefEntryVisitor
+ARGV.options do |opts|
+  opts.on("-pPO", "--po=PO", "PO file") do |po|
+    RD::RD2RefEntryVisitor.po = po
+  end
+end
