@@ -13,8 +13,7 @@
 #include "cut-test-result.h"
 #include "cut-utils.h"
 #include "cut-test-runner.h"
-#include "cuttest-utils.h"
-#include "cuttest-assertions.h"
+#include "lib/cuttest-assertions.h"
 
 void test_equal_int(void);
 void test_equal_string(void);
@@ -45,11 +44,10 @@ void test_equal_fixture_data_string (void);
 void test_equal_fixture_data_string_without_file (void);
 void test_error_errno (void);
 
-static gboolean need_cleanup;
 static gboolean compare_function_is_called;
 static gchar *tmp_file_name;
 
-static CutTest *test_object;
+static CutTest *test;
 static CutRunContext *run_context;
 static CutTestContext *test_context;
 static CutTestResult *test_result;
@@ -67,37 +65,37 @@ error_equal_string_with_null (void)
 }
 
 static void
-dummy_error_test_function (void)
+stub_error_test_function (void)
 {
     cut_error("This test should error");
 }
 
 static void
-dummy_fail_test_function (void)
+stub_fail_test_function (void)
 {
     cut_fail("This test should fail");
 }
 
 static void
-dummy_pend_test_function (void)
+stub_pend_test_function (void)
 {
     cut_pend("This test has been pending ever!");
 }
 
 static void
-dummy_notify_test_function (void)
+stub_notify_test_function (void)
 {
     cut_notify("This test has been notifying ever!");
 }
 
 static void
-dummy_assert_message_test_function (void)
+stub_assert_message_test_function (void)
 {
     cut_assert(FALSE, "The message of %s", "assertion");
 }
 
 static void
-dummy_assert_message_with_format_string (void)
+stub_assert_message_with_format_string (void)
 {
     cut_assert_equal_string("%s", "%d",
                             "%s and %s have format string",
@@ -113,24 +111,22 @@ cb_collect_result (CutTest *test, CutTestContext *test_context,
 }
 
 static gboolean
-run (CutTest *test)
+run (void)
 {
     gboolean success;
     CutTestContext *original_test_context;
 
-    need_cleanup = TRUE;
-
-    test_object = test;
+    cut_assert_not_null(test);
 
     run_context = cut_test_runner_new();
 
-    test_context = cut_test_context_new(NULL, NULL, test_object);
+    test_context = cut_test_context_new(NULL, NULL, NULL, test);
     cut_test_context_set_fixture_data_dir(test_context,
                                           cuttest_get_base_dir(),
                                           "fixtures", "assertions", NULL);
     original_test_context = get_current_test_context();
     set_current_test_context(test_context);
-    success = cut_test_run(test_object, test_context, run_context);
+    success = cut_test_run(test, test_context, run_context);
     set_current_test_context(original_test_context);
 
     return success;
@@ -139,10 +135,9 @@ run (CutTest *test)
 void
 setup (void)
 {
-    need_cleanup = FALSE;
     compare_function_is_called = FALSE;
     tmp_file_name = NULL;
-    test_object = NULL;
+    test = NULL;
     run_context = NULL;
     test_context = NULL;
     test_result = NULL;
@@ -156,11 +151,8 @@ teardown (void)
         g_free(tmp_file_name);
     }
 
-    if (!need_cleanup)
-        return;
-
-    if (test_object)
-        g_object_unref(test_object);
+    if (test)
+        g_object_unref(test);
     if (run_context)
         g_object_unref(run_context);
     if (test_context)
@@ -194,14 +186,12 @@ equal_string_with_diff (void)
 void
 test_equal_string_with_diff (void)
 {
-    CutTest *test;
-
     test = cut_test_new("assert-equal-string-with-diff",
                         equal_string_with_diff);
     g_signal_connect(test, "failure", G_CALLBACK(cb_collect_result),
                      &test_result);
-    cut_assert(!run(test));
-    cut_assert_test_result_summary(run_context, 0, 0, 1, 0, 0, 0, 0);
+    cut_assert_false(run());
+    cut_assert_test_result_summary(run_context, 0, 0, 0, 1, 0, 0, 0, 0);
     cut_assert_equal_string("<\"abc def ghi jkl\" == \"abc DEF ghi jkl\">\n"
                             "expected: <abc def ghi jkl>\n"
                             " but was: <abc DEF ghi jkl>\n"
@@ -251,61 +241,50 @@ test_null (void)
 void
 test_error_equal_string_with_null (void)
 {
-    CutTest *test;
-
     test = cut_test_new("error-equal-string-with-null",
                         error_equal_string_with_null);
-    cut_assert(test, "Creating a new CutTest object failed");
-
-    cut_assert(!run(test));
+    cut_assert_not_null(test);
+    cut_assert_false(run());
 }
 
 void
 test_error_equal_string (void)
 {
-    CutTest *test;
-
-    test = cut_test_new("error-equal-string",
-                        error_equal_string);
-    cut_assert(test, "Creating a new CutTest object failed");
-
-    cut_assert(!run(test));
+    test = cut_test_new("error-equal-string", error_equal_string);
+    cut_assert_not_null(test);
+    cut_assert_false(run());
 }
 
 void
 test_error (void)
 {
-    CutTest *test;
+    test = cut_test_new("stub-error-test", stub_error_test_function);
+    cut_assert_not_null(test);
 
-    test = cut_test_new("dummy-error-test", dummy_error_test_function);
-    cut_assert(test, "Creating a new CutTest object failed");
-
-    cut_assert(!run(test));
-    cut_assert_test_result_summary(run_context, 0, 0, 0, 1, 0, 0, 0);
+    cut_assert_false(run());
+    cut_assert_test_result_summary(run_context, 0, 0, 0, 0, 1, 0, 0, 0);
     cut_assert_test_result(run_context, 0, CUT_TEST_RESULT_ERROR,
-                           "dummy-error-test",
+                           "stub-error-test",
                            "This test should error", NULL,
-                           "dummy_error_test_function");
+                           "stub_error_test_function");
 }
 
 void
 test_pending (void)
 {
-    CutTest *test;
-
-    test = cut_test_new("dummy-pend-test", dummy_pend_test_function);
-    cut_assert(test, "Creating a new CutTest object failed");
+    test = cut_test_new("stub-pend-test", stub_pend_test_function);
+    cut_assert_not_null(test);
 
     g_signal_connect(test, "pending", G_CALLBACK(cb_collect_result),
                      &test_result);
-    cut_assert(!run(test), "cut_pend() did not return FALSE!");
+    cut_assert_false(run(), "cut_pend() did not return FALSE!");
     g_signal_handlers_disconnect_by_func(test,
                                          G_CALLBACK(cb_collect_result),
                                          &test_result);
 
-    cut_assert(test_result,
-               "Could not get a CutTestResult object "
-               "since \"pending\" signal was not emmitted.");
+    cut_assert_not_null(test_result,
+                        "Could not get a CutTestResult object "
+                        "since \"pending\" signal was not emitted.");
     cut_assert_equal_int(CUT_TEST_RESULT_PENDING,
                          cut_test_result_get_status(test_result));
 }
@@ -313,21 +292,19 @@ test_pending (void)
 void
 test_notification (void)
 {
-    CutTest *test;
-
-    test = cut_test_new("dummy-notify-test", dummy_notify_test_function);
-    cut_assert(test, "Creating a new CutTest object failed");
+    test = cut_test_new("stub-notify-test", stub_notify_test_function);
+    cut_assert_not_null(test);
 
     g_signal_connect(test, "notification", G_CALLBACK(cb_collect_result),
                      &test_result);
-    cut_assert(run(test), "cut_notify() did return FALSE!");
+    cut_assert_true(run(), "cut_notify() did return FALSE!");
     g_signal_handlers_disconnect_by_func(test,
                                          G_CALLBACK(cb_collect_result),
                                          &test_result);
 
-    cut_assert(test_result,
-               "Could not get a CutTestResult object "
-               "since \"notification\" signal was not emmitted.");
+    cut_assert_not_null(test_result,
+                        "Could not get a CutTestResult object "
+                        "since \"notification\" signal was not emitted.");
     cut_assert_equal_int(CUT_TEST_RESULT_NOTIFICATION,
                          cut_test_result_get_status(test_result));
 }
@@ -335,20 +312,18 @@ test_notification (void)
 void
 test_fail (void)
 {
-    CutTest *test;
-
-    test = cut_test_new("dummy-fail-test", dummy_fail_test_function);
-    cut_assert(test);
+    test = cut_test_new("stub-fail-test", stub_fail_test_function);
+    cut_assert_not_null(test);
 
     g_signal_connect(test, "failure", G_CALLBACK(cb_collect_result),
                      &test_result);
-    cut_assert(!run(test));
+    cut_assert_false(run());
     g_signal_handlers_disconnect_by_func(test,
                                          G_CALLBACK(cb_collect_result),
                                          &test_result);
-    cut_assert(test_result,
-               "Could not get a CutTestResult object "
-               "since \"failure\" signal was not emmitted.");
+    cut_assert_not_null(test_result,
+                        "Could not get a CutTestResult object "
+                        "since \"failure\" signal was not emitted.");
     cut_assert_equal_int(CUT_TEST_RESULT_FAILURE,
                          cut_test_result_get_status(test_result));
 }
@@ -356,21 +331,19 @@ test_fail (void)
 void
 test_assert_message (void)
 {
-    CutTest *test;
-
-    test = cut_test_new("dummy-assertion-message-test",
-                        dummy_assert_message_test_function);
-    cut_assert(test);
+    test = cut_test_new("stub-assertion-message-test",
+                        stub_assert_message_test_function);
+    cut_assert_not_null(test);
 
     g_signal_connect(test, "failure", G_CALLBACK(cb_collect_result),
                      &test_result);
-    cut_assert(!run(test));
+    cut_assert_false(run());
     g_signal_handlers_disconnect_by_func(test,
                                          G_CALLBACK(cb_collect_result),
                                          &test_result);
-    cut_assert(test_result,
-               "Could not get a CutTestResult object "
-               "since \"failure\" signal was not emmitted.");
+    cut_assert_not_null(test_result,
+                        "Could not get a CutTestResult object "
+                        "since \"failure\" signal was not emitted.");
     cut_assert_equal_int(CUT_TEST_RESULT_FAILURE,
                          cut_test_result_get_status(test_result));
     cut_assert_equal_string("The message of assertion",
@@ -380,21 +353,19 @@ test_assert_message (void)
 void
 test_assert_message_with_format_string (void)
 {
-    CutTest *test;
-
-    test = cut_test_new("dummy-assert-message-with-string",
-                        dummy_assert_message_with_format_string);
-    cut_assert(test);
+    test = cut_test_new("stub-assert-message-with-string",
+                        stub_assert_message_with_format_string);
+    cut_assert_not_null(test);
 
     g_signal_connect(test, "failure", G_CALLBACK(cb_collect_result),
                      &test_result);
-    cut_assert(!run(test));
+    cut_assert_false(run());
     g_signal_handlers_disconnect_by_func(test,
                                          G_CALLBACK(cb_collect_result),
                                          &test_result);
-    cut_assert(test_result,
-               "Could not get a CutTestResult object "
-               "since \"failure\" signal was not emmitted.");
+    cut_assert_not_null(test_result,
+                        "Could not get a CutTestResult object "
+                        "since \"failure\" signal was not emitted.");
     cut_assert_equal_int(CUT_TEST_RESULT_FAILURE,
                          cut_test_result_get_status(test_result));
     cut_assert_equal_string("<\"%s\" == \"%d\">\n"
@@ -415,9 +386,9 @@ compare_function (gpointer a, gpointer b)
 void
 test_assert_equal_function (void)
 {
-    cut_assert(!compare_function_is_called);
+    cut_assert_false(compare_function_is_called);
     cut_assert_equal(compare_function, "o", "o");
-    cut_assert(compare_function_is_called);
+    cut_assert_true(compare_function_is_called);
 }
 
 static gboolean
@@ -438,22 +409,16 @@ just_call_fail_in_nested_function (void)
 void
 test_failure_from_nested_function (void)
 {
-    CutTest *test;
     CutTestResult *result;
-    const GList *results;
 
     test = cut_test_new("fail from nested function",
                         just_call_fail_in_nested_function);
-    cut_assert(test);
+    cut_assert_not_null(test);
 
-    cut_assert(!run(test));
+    cut_assert_false(run());
 
-    cut_assert(run_context);
-    cut_assert(1, cut_run_context_get_n_tests(run_context));
-    cut_assert(1, cut_run_context_get_n_assertions(run_context));
-    results = cut_run_context_get_results(run_context);
-    cut_assert(1, g_list_length((GList *)results));
-    cut_assert(1, cut_run_context_get_n_failures(run_context));
+    cut_assert_not_null(run_context);
+    cut_assert_test_result_summary(run_context, 0, 0, 0, 1, 0, 0, 0, 0);
 
     result = cut_run_context_get_results(run_context)->data;
     cut_assert_equal_string("Fail from nested function",
@@ -470,11 +435,9 @@ null_string_assertions (void)
 void
 test_null_string (void)
 {
-    CutTest *test;
-
     test = cut_test_new("assert-null-string", null_string_assertions);
-    cut_assert(!run(test));
-    cut_assert_test_result_summary(run_context, 0, 1, 1, 0, 0, 0, 0);
+    cut_assert_false(run());
+    cut_assert_test_result_summary(run_context, 0, 1, 0, 1, 0, 0, 0, 0);
 }
 
 static void
@@ -489,12 +452,10 @@ equal_string_with_free_assertions (void)
 void
 test_equal_string_with_free (void)
 {
-    CutTest *test;
-
     test = cut_test_new("assert-string-equal-string-with-free",
                         equal_string_with_free_assertions);
-    cut_assert(!run(test));
-    cut_assert_test_result_summary(run_context, 0, 3, 1, 0, 0, 0, 0);
+    cut_assert_false(run());
+    cut_assert_test_result_summary(run_context, 0, 3, 0, 1, 0, 0, 0, 0);
 }
 
 static void
@@ -510,11 +471,9 @@ assert_errno_for_eacces (void)
 void
 test_assert_errno (void)
 {
-    CutTest *test;
-
     test = cut_test_new("assert-errno-for-eacces", assert_errno_for_eacces);
-    cut_assert(!run(test));
-    cut_assert_test_result_summary(run_context, 0, 1, 1, 0, 0, 0, 0);
+    cut_assert_false(run());
+    cut_assert_test_result_summary(run_context, 0, 1, 0, 1, 0, 0, 0, 0);
 }
 
 static void
@@ -528,11 +487,9 @@ omit_test (void)
 void
 test_omit (void)
 {
-    CutTest *test;
-
     test = cut_test_new("omit-test", omit_test);
-    cut_assert(run(test));
-    cut_assert_test_result_summary(run_context, 0, 1, 0, 0, 0, 0, 1);
+    cut_assert_true(run());
+    cut_assert_test_result_summary(run_context, 0, 1, 1, 0, 0, 0, 0, 1);
 }
 
 static void
@@ -558,11 +515,9 @@ path_exist_test (void)
 void
 test_path_exist (void)
 {
-    CutTest *test;
-
     test = cut_test_new("path-exist-test", path_exist_test);
-    cut_assert(!run(test));
-    cut_assert_test_result_summary(run_context, 0, 1, 1, 0, 0, 0, 0);
+    cut_assert_false(run());
+    cut_assert_test_result_summary(run_context, 0, 1, 0, 1, 0, 0, 0, 0);
 }
 
 static void
@@ -587,11 +542,9 @@ path_not_exist_test (void)
 void
 test_path_not_exist (void)
 {
-    CutTest *test;
-
     test = cut_test_new("path-not-exist-test", path_not_exist_test);
-    cut_assert(!run(test));
-    cut_assert_test_result_summary(run_context, 0, 1, 1, 0, 0, 0, 0);
+    cut_assert_false(run());
+    cut_assert_test_result_summary(run_context, 0, 1, 0, 1, 0, 0, 0, 0);
 }
 
 static void
@@ -604,11 +557,9 @@ match_test (void)
 void
 test_match (void)
 {
-    CutTest *test;
-
     test = cut_test_new("match-test", match_test);
-    cut_assert(!run(test));
-    cut_assert_test_result_summary(run_context, 0, 1, 1, 0, 0, 0, 0);
+    cut_assert_false(run());
+    cut_assert_test_result_summary(run_context, 0, 1, 0, 1, 0, 0, 0, 0);
 }
 
 static void
@@ -623,11 +574,9 @@ equal_pointer_test (void)
 void
 test_equal_pointer (void)
 {
-    CutTest *test;
-
     test = cut_test_new("equal-pointer-test", equal_pointer_test);
-    cut_assert(!run(test));
-    cut_assert_test_result_summary(run_context, 0, 1, 1, 0, 0, 0, 0);
+    cut_assert_false(run());
+    cut_assert_test_result_summary(run_context, 0, 1, 0, 1, 0, 0, 0, 0);
 }
 
 static void
@@ -641,12 +590,10 @@ equal_fixture_data_string_test (void)
 void
 test_equal_fixture_data_string (void)
 {
-    CutTest *test;
-
     test = cut_test_new("equal-fixture-data-sting-test",
                         equal_fixture_data_string_test);
-    cut_assert(!run(test));
-    cut_assert_test_result_summary(run_context, 0, 2, 1, 0, 0, 0, 0);
+    cut_assert_false(run());
+    cut_assert_test_result_summary(run_context, 0, 2, 0, 1, 0, 0, 0, 0);
 }
 
 static void
@@ -658,12 +605,10 @@ equal_fixture_data_string_test_without_file (void)
 void
 test_equal_fixture_data_string_without_file (void)
 {
-    CutTest *test;
-
     test = cut_test_new("equal-fixture-data-sting-test-without-file",
                         equal_fixture_data_string_test_without_file);
-    cut_assert(!run(test));
-    cut_assert_test_result_summary(run_context, 0, 0, 0, 1, 0, 0, 0);
+    cut_assert_false(run());
+    cut_assert_test_result_summary(run_context, 0, 0, 0, 0, 1, 0, 0, 0);
 }
 
 static void
@@ -679,12 +624,11 @@ error_errno (void)
 void
 test_error_errno (void)
 {
-    CutTest *test;
     CutTestResult *result;
 
     test = cut_test_new("error-errno", error_errno);
-    cut_assert(!run(test));
-    cut_assert_test_result_summary(run_context, 0, 0, 0, 1, 0, 0, 0);
+    cut_assert_false(run());
+    cut_assert_test_result_summary(run_context, 0, 0, 0, 0, 1, 0, 0, 0);
 
     result = cut_run_context_get_results(run_context)->data;
     cut_assert_equal_string("Should error",
