@@ -1,49 +1,74 @@
-#include "cutter.h"
-#include "cut-loader.h"
+#include <cutter.h>
+#include <cutter/cut-loader.h>
+#include <cutter/cut-test-runner.h>
 
-#include "cuttest-utils.h"
+#include "lib/cuttest-assertions.h"
 
 void test_load_function (void);
 void test_load_startup_and_shutdown_function (void);
 void test_fail_to_load (void);
+void test_load_test_iterator (void);
 
-static CutLoader *test_loader;
+static CutLoader *loader;
 static CutTestCase *test_case;
+static CutRunContext *run_context;
 static gchar **test_names;
 
 void
 setup (void)
 {
-    gchar *test_path;
-
-    test_path = g_build_filename(cuttest_get_base_dir(),
-                                 "loader_test_dir",
-                                 ".libs",
-                                 "dummy_loader_test." G_MODULE_SUFFIX,
-                                 NULL);
-    test_loader = cut_loader_new(test_path);
-    g_free(test_path);
-
+    loader = NULL;
     test_case = NULL;
     test_names = NULL;
+    run_context = NULL;
 }
 
 void
 teardown (void)
 {
-    if (test_loader)
-        g_object_unref(test_loader);
+    if (loader)
+        g_object_unref(loader);
     if (test_case)
         g_object_unref(test_case);
     if (test_names)
         g_strfreev(test_names);
+    if (run_context)
+        g_object_unref(run_context);
+}
+
+static CutLoader *
+loader_new (const gchar *directory, const gchar *module_name)
+{
+    CutLoader *loader;
+    gchar *test_path;
+
+    test_path = g_build_filename(cuttest_get_base_dir(),
+                                 "fixtures",
+                                 "loader",
+                                 directory,
+                                 ".libs",
+                                 module_name,
+                                 NULL);
+    loader = cut_loader_new(test_path);
+    g_free(test_path);
+
+    return loader;
+}
+
+static gboolean
+run (void)
+{
+    cut_assert_not_null(test_case);
+
+    run_context = cut_test_runner_new();
+    return cut_test_case_run(test_case, run_context);
 }
 
 static gchar *expected_functions[] = {
     "test_abcdefghijklmnopqratuvwzyz_ABCDEFGHIJKLMNOPQRSTUVWXYZ_0123456789",
-    "test_dummy_function1",
-    "test_dummy_function2",
-    "test_dummy_function3",
+    "test_stub_function1",
+    "test_stub_function2",
+    "test_stub_function3",
     NULL
 };
 
@@ -65,7 +90,8 @@ test_load_function (void)
     const gchar *target_test_names[] = {"/.*/", NULL};
     gint i;
 
-    test_case = cut_loader_load_test_case(test_loader);
+    loader = loader_new("test", "stub_loader_test." G_MODULE_SUFFIX);
+    test_case = cut_loader_load_test_case(loader);
     cut_assert(test_case);
     cut_assert_equal_int(4, cut_test_case_get_n_tests(test_case, NULL));
     cut_assert_equal_int(4, cut_test_case_get_n_tests(test_case,
@@ -95,7 +121,8 @@ test_load_startup_and_shutdown_function (void)
     CutStartupFunction startup_function = NULL;
     CutShutdownFunction shutdown_function = NULL;
 
-    test_case = cut_loader_load_test_case(test_loader);
+    loader = loader_new("test", "stub_loader_test." G_MODULE_SUFFIX);
+    test_case = cut_loader_load_test_case(loader);
     cut_assert(test_case);
 
     g_object_get(G_OBJECT(test_case),
@@ -109,20 +136,43 @@ test_load_startup_and_shutdown_function (void)
 void
 test_fail_to_load (void)
 {
-    CutLoader *loader;
-    gchar *test_path;
+    loader = loader_new("module", "cannot_load_module." G_MODULE_SUFFIX);
+    cut_assert_not_null(loader);
 
-    test_path = g_build_filename(cuttest_get_base_dir(),
-                                 "module_test_dir",
-                                 ".libs",
-                                 "cannot_load_module." G_MODULE_SUFFIX,
-                                 NULL);
-    loader = cut_loader_new(test_path);
-    g_free(test_path);
+    test_case = cut_loader_load_test_case(loader);
+    cut_assert_null(test_case);
+}
 
-    cut_assert(loader);
-    cut_assert_null(cut_loader_load_test_case(loader));
-    g_object_unref(loader);
+void
+test_load_test_iterator (void)
+{
+    const GList *tests;
+    CutTestIterator *test_iterator;
+    CutIteratedTestFunction iterated_test_function = NULL;
+    CutDataSetupFunction data_setup_function = NULL;
+
+    loader = loader_new("iterator", "success_iterated_test." G_MODULE_SUFFIX);
+    cut_assert_not_null(loader);
+
+    test_case = cut_loader_load_test_case(loader);
+    cut_assert_not_null(test_case);
+    cut_assert_equal_int(1, cut_test_case_get_n_tests(test_case, NULL));
+
+    tests = cut_test_container_get_children(CUT_TEST_CONTAINER(test_case));
+    cut_assert_not_null(tests);
+
+    test_iterator = tests->data;
+    cut_assert_not_null(test_iterator);
+
+    g_object_get(test_iterator,
+                 "iterated-test-function", &iterated_test_function,
+                 "data-setup-function", &data_setup_function,
+                 NULL);
+    cut_assert_not_null(iterated_test_function);
+    cut_assert_not_null(data_setup_function);
+
+    cut_assert_true(run());
+    cut_assert_test_result_summary(run_context, 2, 2, 2, 0, 0, 0, 0, 0);
 }
 
 /*
