@@ -1,8 +1,8 @@
-#include "cutter.h"
-#include "cut-module-factory.h"
-#include "cut-module-factory-utils.h"
+#include <cutter.h>
+#include <cutter/cut-module-factory.h>
+#include <cutter/cut-module-factory-utils.h>
 
-#include "cuttest-utils.h"
+#include "lib/cuttest-utils.h"
 
 void test_module_names (void);
 void test_module_arguments (void);
@@ -20,7 +20,8 @@ startup (void)
     cut_module_factory_init();
 
     factory_dir = g_build_filename(cuttest_get_base_dir(),
-                                   "factory_test_dir",
+                                   "fixtures",
+                                   "factory",
                                    NULL);
     cut_module_factory_load_all(factory_dir);
     g_free(factory_dir);
@@ -78,7 +79,7 @@ test_module_arguments (void)
     gint argc = 3;
     gchar *argv[] = {
         "test program",
-        "-f", "dummy_function",
+        "-f", "stub_function",
         NULL,
     };
     gchar **copy_argv;
@@ -98,7 +99,7 @@ test_module_arguments (void)
     g_object_get(object,
                  "name", &function_name,
                  NULL);
-    cut_assert_equal_string_with_free("dummy_function", function_name);
+    cut_assert_equal_string_with_free("stub_function", function_name);
 
     g_object_unref(factory);
     factory = NULL;
