@@ -23,7 +23,10 @@ void
 test_fork (void)
 {
     int pid;
+
     pid = cut_process_fork(process);
+    if (pid == -1 && errno == ENOSYS)
+        cut_omit("cut_process_fork() can't be used on the environment.");
 
     if (pid == 0) {
         _exit(EXIT_SUCCESS);
