@@ -55,7 +55,7 @@ void
 test_get_status (void)
 {
     result = cut_test_result_new(CUT_TEST_RESULT_SUCCESS,
-                                 NULL, NULL, NULL,
+                                 NULL, NULL, NULL, NULL, NULL,
                                  "user-message",
                                  "system-message",
                                  "function-name",
@@ -66,7 +66,7 @@ test_get_status (void)
     g_object_unref(result);
 
     result = cut_test_result_new(CUT_TEST_RESULT_FAILURE,
-                                 NULL, NULL, NULL,
+                                 NULL, NULL, NULL, NULL, NULL,
                                  "user-message",
                                  "system-message",
                                  "function-name",
@@ -77,7 +77,7 @@ test_get_status (void)
     g_object_unref(result);
 
     result = cut_test_result_new(CUT_TEST_RESULT_ERROR,
-                                 NULL, NULL, NULL,
+                                 NULL, NULL, NULL, NULL, NULL,
                                  "user-message",
                                  "system-message",
                                  "function-name",
@@ -88,7 +88,7 @@ test_get_status (void)
     g_object_unref(result);
 
     result = cut_test_result_new(CUT_TEST_RESULT_PENDING,
-                                 NULL, NULL, NULL,
+                                 NULL, NULL, NULL, NULL, NULL,
                                  "user-message",
                                  "system-message",
                                  "function-name",
@@ -102,7 +102,7 @@ void
 test_get_message_full (void)
 {
     result = cut_test_result_new(CUT_TEST_RESULT_SUCCESS,
-                                 NULL, NULL, NULL,
+                                 NULL, NULL, NULL, NULL, NULL,
                                  "user-message",
                                  "system-message",
                                  "function-name",
@@ -120,7 +120,7 @@ void
 test_get_message_only_user (void)
 {
     result = cut_test_result_new(CUT_TEST_RESULT_SUCCESS,
-                                 NULL, NULL, NULL,
+                                 NULL, NULL, NULL, NULL, NULL,
                                  "user-message",
                                  NULL,
                                  "function-name",
@@ -137,7 +137,7 @@ void
 test_get_message_only_system (void)
 {
     result = cut_test_result_new(CUT_TEST_RESULT_SUCCESS,
-                                 NULL, NULL, NULL,
+                                 NULL, NULL, NULL, NULL, NULL,
                                  NULL,
                                  "system-message",
                                  "function-name",
@@ -154,7 +154,7 @@ void
 test_get_message_none (void)
 {
     result = cut_test_result_new(CUT_TEST_RESULT_FAILURE,
-                                 NULL, NULL, NULL,
+                                 NULL, NULL, NULL, NULL, NULL,
                                  NULL,
                                  NULL,
                                  "function-name",
@@ -180,7 +180,7 @@ void
 test_set_messages (void)
 {
     result = cut_test_result_new(CUT_TEST_RESULT_FAILURE,
-                                 NULL, NULL, NULL,
+                                 NULL, NULL, NULL, NULL, NULL,
                                  "user-message",
                                  "system-message",
                                  "function-name",
@@ -209,7 +209,7 @@ void
 test_get_function_name (void)
 {
     result = cut_test_result_new(CUT_TEST_RESULT_SUCCESS,
-                                 NULL, NULL, NULL,
+                                 NULL, NULL, NULL, NULL, NULL,
                                  "user-message",
                                  "system-message",
                                  "function-name",
@@ -223,7 +223,7 @@ test_get_function_name (void)
     g_object_unref(result);
 
     result = cut_test_result_new(CUT_TEST_RESULT_FAILURE,
-                                 NULL, NULL, NULL,
+                                 NULL, NULL, NULL, NULL, NULL,
                                  NULL,
                                  NULL,
                                  NULL,
@@ -237,7 +237,7 @@ void
 test_get_filename (void)
 {
     result = cut_test_result_new(CUT_TEST_RESULT_SUCCESS,
-                                 NULL, NULL, NULL,
+                                 NULL, NULL, NULL, NULL, NULL,
                                  "user-message",
                                  "system-message",
                                  "function-name",
@@ -251,7 +251,7 @@ test_get_filename (void)
     g_object_unref(result);
 
     result = cut_test_result_new(CUT_TEST_RESULT_FAILURE,
-                                 NULL, NULL, NULL,
+                                 NULL, NULL, NULL, NULL, NULL,
                                  NULL,
                                  NULL,
                                  NULL,
@@ -264,7 +264,7 @@ void
 test_get_line (void)
 {
     result = cut_test_result_new(CUT_TEST_RESULT_SUCCESS,
-                                 NULL, NULL, NULL,
+                                 NULL, NULL, NULL, NULL, NULL,
                                  "user-message",
                                  "system-message",
                                  "function-name",
@@ -277,7 +277,7 @@ test_get_line (void)
     g_object_unref(result);
 
     result = cut_test_result_new(CUT_TEST_RESULT_FAILURE,
-                                 NULL, NULL, NULL,
+                                 NULL, NULL, NULL, NULL, NULL,
                                  NULL,
                                  NULL,
                                  NULL,
@@ -287,7 +287,7 @@ test_get_line (void)
     g_object_unref(result);
 
     result = cut_test_result_new(CUT_TEST_RESULT_FAILURE,
-                                 NULL, NULL, NULL,
+                                 NULL, NULL, NULL, NULL, NULL,
                                  NULL,
                                  NULL,
                                  NULL,
@@ -332,7 +332,7 @@ void
 test_get_test_suite (void)
 {
     result = cut_test_result_new(CUT_TEST_RESULT_SUCCESS,
-                                 NULL, NULL, NULL,
+                                 NULL, NULL, NULL, NULL, NULL,
                                  NULL, NULL, NULL, NULL, 0);
     cut_assert_null(cut_test_result_get_test_suite(result));
 
@@ -379,10 +379,10 @@ test_new_from_xml (void)
     const gchar xml[] =
         "<result>\n"
         "  <test-case>\n"
-        "    <name>dummy test case</name>\n"
+        "    <name>stub test case</name>\n"
         "  </test-case>\n"
         "  <test>\n"
-        "    <name>dummy-error-test</name>\n"
+        "    <name>stub-error-test</name>\n"
         "    <description>Error Test</description>\n"
         "    <option>\n"
         "      <name>bug</name>\n"
@@ -395,22 +395,22 @@ test_new_from_xml (void)
         "    <entry>\n"
         "      <file>test-cut-report-xml.c</file>\n"
         "      <line>31</line>\n"
-        "      <info>dummy_error_test()</info>\n"
+        "      <info>stub_error_test()</info>\n"
         "    </entry>\n"
         "  </backtrace>\n"
         "  <elapsed>0.000100</elapsed>\n"
         "</result>\n";
 
     result = cut_test_result_new_from_xml(xml, -1, &error);
-    cut_assert_g_error(error);
+    gcut_assert_error(error);
     cut_assert(result);
 
     test = cut_test_result_get_test(result);
     cut_assert(test);
 
-    cut_assert_equal_string("dummy test case",
+    cut_assert_equal_string("stub test case",
                             cut_test_result_get_test_case_name(result));
-    cut_assert_equal_string("dummy-error-test",
+    cut_assert_equal_string("stub-error-test",
                             cut_test_result_get_test_name(result));
     cut_assert_equal_int(CUT_TEST_RESULT_ERROR,
                          cut_test_result_get_status(result));
@@ -418,7 +418,7 @@ test_new_from_xml (void)
     cut_assert_equal_int(31, cut_test_result_get_line(result));
     cut_assert_equal_string("test-cut-report-xml.c",
                             cut_test_result_get_filename(result));
-    cut_assert_equal_string("dummy_error_test",
+    cut_assert_equal_string("stub_error_test",
                             cut_test_result_get_function_name(result));
     cut_assert_equal_string("This test should error",
                             cut_test_result_get_message(result));
@@ -476,14 +476,14 @@ test_new_from_xml_with_invalid_info (void)
         "<result>\n"
         "  <backtrace>\n"
         "    <entry>\n"
-        "      <info>dummy_error_test</info>\n"
+        "      <info>stub_error_test</info>\n"
         "    </entry>\n"
         "  </backtrace>\n"
         "</result>\n";
 
-    cut_assert_new_from_xml_error("Error on line 4 char 30: "
+    cut_assert_new_from_xml_error("Error on line 4 char 29: "
                                   "/result/backtrace/entry/info: "
-                                  "invalid function name: dummy_error_test",
+                                  "invalid function name: stub_error_test",
                                   xml);
 }
 
