@@ -1,7 +1,7 @@
 #include <cutter.h>
 #include <cutter/cut-test-runner.h>
 
-#include "cuttest-utils.h"
+#include "lib/cuttest-utils.h"
 
 void test_sort_test_cases (void);
 void test_n_ (void);
@@ -47,37 +47,37 @@ teardown (void)
 }
 
 static void
-dummy_success_function (void)
+stub_success_function (void)
 {
     cut_assert(1);
 }
 
 static void
-dummy_failure_function (void)
+stub_failure_function (void)
 {
     cut_fail("This test should fail");
 }
 
 static void
-dummy_omit_function (void)
+stub_omit_function (void)
 {
     cut_omit("This test should be omitted.");
 }
 
 static void
-dummy_pending_function (void)
+stub_pending_function (void)
 {
     cut_pend("This test has been pending ever!");
 }
 
 static void
-dummy_notification_function (void)
+stub_notification_function (void)
 {
     cut_notify("This test has been notifying ever!");
 }
 
 static void
-dummy_error_function (void)
+stub_error_function (void)
 {
     cut_error("This test should error");
 }
@@ -159,18 +159,18 @@ test_sort_test_cases (void)
 void
 test_n_ (void)
 {
-    test_case = cut_test_case_new("dummy test case",
+    test_case = cut_test_case_new("stub test case",
                                   NULL,
                                   NULL,
                                   get_current_test_context,
                                   set_current_test_context,
                                   NULL, NULL);
-    cuttest_add_test(test_case, "test_1", dummy_success_function);
-    cuttest_add_test(test_case, "test_2", dummy_failure_function);
-    cuttest_add_test(test_case, "test_3", dummy_omit_function);
-    cuttest_add_test(test_case, "test_4", dummy_pending_function);
-    cuttest_add_test(test_case, "test_5", dummy_notification_function);
-    cuttest_add_test(test_case, "test_6", dummy_error_function);
+    cuttest_add_test(test_case, "test_1", stub_success_function);
+    cuttest_add_test(test_case, "test_2", stub_failure_function);
+    cuttest_add_test(test_case, "test_3", stub_omit_function);
+    cuttest_add_test(test_case, "test_4", stub_pending_function);
+    cuttest_add_test(test_case, "test_5", stub_notification_function);
+    cuttest_add_test(test_case, "test_6", stub_error_function);
 
     cut_assert(!cut_test_case_run(test_case, run_context));
 
@@ -242,13 +242,13 @@ test_ready_signal (void)
 
     suite = cut_test_suite_new_empty();
 
-    test_case = cut_test_case_new("dummy test case",
+    test_case = cut_test_case_new("stub test case",
                                   NULL,
                                   NULL,
                                   get_current_test_context,
                                   set_current_test_context,
                                   NULL, NULL);
-    cuttest_add_test(test_case, "test_1", dummy_success_function);
+    cuttest_add_test(test_case, "test_1", stub_success_function);
     cut_test_suite_add_test_case(suite, test_case);
     g_object_unref(test_case);
     test_case = NULL;
