@@ -53,7 +53,6 @@ static const gchar *help_message;
 #define cut_assert_exit_failure()               \
     cut_assert_exit_status(EXIT_FAILURE)
 
-
 void
 setup (void)
 {
@@ -211,6 +210,10 @@ test_help_all (void)
         "  --class=CLASS                                   Program class as used by the window manager" LINE_FEED_CODE
         "  --gtk-name=NAME                                 Program name as used by the window manager" LINE_FEED_CODE
         "  --screen=SCREEN                                 X screen to use" LINE_FEED_CODE
+#  ifdef HAVE_GTK_ENABLE_DEBUG
+        "  --gdk-debug=FLAGS                               Gdk debugging flags to set" LINE_FEED_CODE
+        "  --gdk-no-debug=FLAGS                            Gdk debugging flags to unset" LINE_FEED_CODE
+#  endif
 #  ifdef GDK_WINDOWING_X11
         "  --sync                                          Make X calls synchronous" LINE_FEED_CODE
 #  elif defined(GDK_WINDOWING_WIN32)
@@ -222,6 +225,10 @@ test_help_all (void)
 #  endif
         "  --gtk-module=MODULES                            Load additional GTK+ modules" LINE_FEED_CODE
         "  --g-fatal-warnings                              Make all warnings fatal" LINE_FEED_CODE
+#  ifdef HAVE_GTK_ENABLE_DEBUG
+        "  --gtk-debug=FLAGS                               GTK+ debugging flags to set" LINE_FEED_CODE
+        "  --gtk-no-debug=FLAGS                            GTK+ debugging flags to unset" LINE_FEED_CODE
+#  endif
         "" LINE_FEED_CODE
 #endif
         "Application Options:" LINE_FEED_CODE
